/* Compiler: ECL 26.3.27                                                      */
/* Source: /build/ecl/src/ecl-26.3.27/src/lsp/setf.lsp                        */
#include <ecl/ecl-cmp.h>
#include "lsp/setf.eclh"
/* function definition for DO-SETF-METHOD-EXPANSION                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L87do_setf_method_expansion(cl_narg narg, cl_object v1name, cl_object v2lambda, cl_object v3args, ...)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[0]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[0]);
 {
  cl_object v4stores_no;
  va_list args; va_start(args,v3args);
  {
   int i = 3;
   if (i >= narg) {
    v4stores_no = ecl_make_int8_t(1);
   } else {
    i++;
    v4stores_no = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v5vars;
   cl_object v6inits;
   cl_object v7all;
   cl_object v8stores;
   v5vars = ECL_NIL;
   v6inits = ECL_NIL;
   v7all = ECL_NIL;
   v8stores = ECL_NIL;
   {
    cl_object v9;
    v9 = v3args;
    goto L10;
L9:;
    {
     cl_object v10item;
     v10item = ecl_car(v9);
     if (ECL_FIXNUMP(v10item)) {
      goto L14;
     }
     if (cl_keywordp(v10item)!=ECL_NIL) {
      goto L14;
     }
     v6inits = CONS(v10item,v6inits);
     v10item = cl_gensym(0);
     v5vars = CONS(v10item,v5vars);
L14:;
     v7all = CONS(v10item,v7all);
    }
    v9 = ecl_cdr(v9);
L10:;
    if (Null(v9)){
     goto L26;
    }
    goto L9;
L26:;
   }
   {
    cl_object v9i;
    v9i = ecl_make_int8_t(0);
    goto L31;
L30:;
    T0 = cl_gensym(0);
    v8stores = CONS(T0,v8stores);
    v9i = ecl_one_plus(v9i);
L31:;
    if (!(ecl_lower(v9i,v4stores_no))){
     goto L37;
    }
    goto L30;
L37:;
   }
   {
    cl_object v9all;
    v9all = cl_nreverse(v7all);
    T0 = cl_nreverse(v5vars);
    T1 = cl_nreverse(v6inits);
    if (Null(v2lambda)){
     goto L41;
    }
    T3 = ecl_append(v8stores,v9all);
    T2 = cl_apply(2, v2lambda, T3);
    goto L40;
L41:;
    T3 = cl_list(2, ECL_SYM("SETF",753), v1name);
    T4 = cl_list(2, ECL_SYM("FUNCTION",398), T3);
    T5 = ecl_append(v8stores,v9all);
    T2 = cl_listX(3, ECL_SYM("FUNCALL",396), T4, T5);
L40:;
    T3 = CONS(v1name,v9all);
    cl_env_copy->nvalues = 5;
    cl_env_copy->values[4] = T3;
    cl_env_copy->values[3] = T2;
    cl_env_copy->values[2] = v8stores;
    cl_env_copy->values[1] = T1;
    cl_env_copy->values[0] = T0;
    return cl_env_copy->values[0];
   }
  }
 }
}
/* function definition for DO-DEFSETF                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_do_defsetf(cl_narg narg, cl_object v1access_fn, cl_object v2function, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(ECL_SYM("DO-DEFSETF",2049));
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(ECL_SYM("DO-DEFSETF",2049));
 {
  va_list args; va_start(args,v2function);
  env0 = ECL_NIL;
  CLV0 = env0 = CONS(v1access_fn,env0);           /*  ACCESS-FN               */
  CLV1 = env0 = CONS(v2function,env0);            /*  FUNCTION                */
  {
   int i = 2;
   if (i >= narg) {
    CLV2 = env0 = CONS(ecl_make_int8_t(1),env0);  /*  STORES-NO               */
   } else {
    i++;
    CLV2 = env0 = CONS(va_arg(args,cl_object),env0); /*  STORES-NO            */
   }
  }
  va_end(args);
  if (!(ECL_SYMBOLP(ECL_CONS_CAR(CLV1)))){
   goto L1;
  }
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC88__lambda15,env0,Cblock,1);
   T0 = v3;
  }
  value0 = si_do_defsetf(3, ECL_CONS_CAR(CLV0), T0, ECL_CONS_CAR(CLV2));
  return value0;
L1:;
  {
   cl_object v3;
   v3 = ecl_make_cclosure_va((cl_objectfn)LC89__lambda17,env0,Cblock,2);
   T0 = v3;
  }
  value0 = si_do_define_setf_method(ECL_CONS_CAR(CLV0), T0);
  return value0;
 }
}
/* function definition for DO-DEFINE-SETF-METHOD                              */
/* optimize speed 1, debug 1, space 1, safety 2                               */
cl_object si_do_define_setf_method(cl_object v1access_fn, cl_object v2function)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = si_put_sysprop(v1access_fn, ECL_SYM("SETF-METHOD",1165), v2function);
 return value0;
}
/* local function DEFSETF                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC90defsetf(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4access_fn;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4access_fn = v5;
  }
  {
   cl_object v5function;
   cl_object v6documentation;
   cl_object v7stores;
   v5function = ECL_NIL;
   v6documentation = ECL_NIL;
   v7stores = ECL_NIL;
   if (Null(ecl_car(v3))){
    goto L13;
   }
   T0 = ecl_car(v3);
   if (ECL_SYMBOLP(T0)) {
    goto L16;
   }
   T0 = ecl_car(v3);
   if (Null(cl_functionp(T0))){
    goto L13;
   }
   goto L14;
L16:;
L14:;
   T0 = ecl_car(v3);
   v5function = cl_list(2, ECL_SYM("QUOTE",682), T0);
   v6documentation = ecl_cadr(v3);
   T0 = cl_gensym(0);
   v7stores = ecl_list1(T0);
   goto L12;
L13:;
   {
    cl_object v8args;
    cl_object v9body;
    cl_object v10decls;
    v8args = ecl_car(v3);
    v9body = ecl_cddr(v3);
    v10decls = ECL_NIL;
    value0 = si_find_declarations(2, v9body, ECL_T);
    {
     const int v11 = cl_env_copy->nvalues;
     v10decls = value0;
     cl_object v12;
     v12 = (v11<=1)? ECL_NIL : cl_env_copy->values[1];
     v9body = v12;
     v12 = (v11<=2)? ECL_NIL : cl_env_copy->values[2];
     v6documentation = v12;
    }
    v7stores = ecl_cadr(v3);
    T0 = ecl_append(v7stores,v8args);
    T1 = cl_listX(3, ECL_SYM("BLOCK",139), v4access_fn, v9body);
    T2 = ecl_list1(T1);
    T3 = ecl_append(v10decls,T2);
    T4 = cl_listX(3, ECL_SYM("LAMBDA",454), T0, T3);
    v5function = cl_list(2, ECL_SYM("FUNCTION",398), T4);
   }
L12:;
   if (Null(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*REGISTER-WITH-PDE-HOOK*",1211)))){
    goto L32;
   }
   T1 = ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*REGISTER-WITH-PDE-HOOK*",1211));
   T2 = cl_copy_tree(ecl_cmp_symbol_value(cl_env_copy,ECL_SYM("*SOURCE-LOCATION*",1210)));
   T3 = cl_list(2, ECL_SYM("QUOTE",682), v4access_fn);
   {
    cl_fixnum v8;
    v8 = ecl_length(v7stores);
    T4 = cl_list(4, ECL_SYM("DO-DEFSETF",2049), T3, v5function, ecl_make_fixnum(v8));
    T0 = ecl_function_dispatch(cl_env_copy,T1)(3, T2, v1, T4);
    goto L31;
   }
L32:;
   T1 = cl_list(2, ECL_SYM("QUOTE",682), v4access_fn);
   {
    cl_fixnum v8;
    v8 = ecl_length(v7stores);
    T0 = cl_list(4, ECL_SYM("DO-DEFSETF",2049), T1, v5function, ecl_make_fixnum(v8));
   }
L31:;
   T1 = si_expand_set_documentation(v4access_fn, ECL_SYM("SETF",753), v6documentation);
   T2 = cl_list(2, ECL_SYM("QUOTE",682), v4access_fn);
   T3 = ecl_list1(T2);
   T4 = ecl_append(T1,T3);
   value0 = cl_listX(4, ECL_SYM("EVAL-WHEN",342), VV[5], T0, T4);
   return value0;
  }
 }
}
static cl_object LC90defsetf_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[7]);
 {
  return LC90defsetf(v8, v9);
 }
}
/* local function DEFINE-SETF-EXPANDER                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC91define_setf_expander(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4access_fn;
  cl_object v5args;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4access_fn = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5args = v6;
  }
  {
   cl_object v6;                                  /*  FUNCTION                */
   cl_object v7;                                  /*  DOCUMENTATION           */
   value0 = (cl_env_copy->function=(ECL_SYM("EXPAND-DEFMACRO",1077)->symbol.gfdef))->cfun.entry(4, v4access_fn, v5args, v3, ECL_SYM("DEFINE-SETF-EXPANDER",283)) /*  EXPAND-DEFMACRO */;
   {
    const int v8 = cl_env_copy->nvalues;
    v6 = value0;
    cl_object v9;
    v9 = (v8<=2)? ECL_NIL : cl_env_copy->values[2];
    v7 = v9;
   }
   T0 = cl_list(2, ECL_SYM("QUOTE",682), v4access_fn);
   T1 = cl_list(2, ECL_SYM("FUNCTION",398), v6);
   T2 = cl_list(3, ECL_SYM("DO-DEFINE-SETF-METHOD",2050), T0, T1);
   T3 = si_expand_set_documentation(v4access_fn, ECL_SYM("SETF",753), v7);
   T4 = cl_list(2, ECL_SYM("QUOTE",682), v4access_fn);
   T5 = ecl_list1(T4);
   T6 = ecl_append(T3,T5);
   value0 = cl_listX(4, ECL_SYM("EVAL-WHEN",342), VV[5], T2, T6);
   return value0;
  }
 }
}
static cl_object LC91define_setf_expander_va(cl_narg narg, cl_object v6, cl_object v7, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[8]);
 {
  return LC91define_setf_expander(v6, v7);
 }
}
/* function definition for GET-SETF-EXPANSION                                 */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L92get_setf_expansion(cl_narg narg, cl_object v1form, ...)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[10]);
 if (ecl_unlikely(narg>2)) FEwrong_num_arguments(VV[10]);
 {
  cl_object v2env;
  va_list args; va_start(args,v1form);
  {
   int i = 1;
   if (i >= narg) {
    v2env = ECL_NIL;
   } else {
    i++;
    v2env = va_arg(args,cl_object);
   }
  }
  va_end(args);
  {
   cl_object v3f;
   v3f = ECL_NIL;
   if (!(ECL_SYMBOLP(v1form))){
    goto L3;
   }
   v3f = cl_macroexpand_1(2, v1form, v2env);
   if (Null(v3f)){
    goto L5;
   }
   if (ecl_equal(v3f,v1form)) {
    goto L5;
   }
   value0 = L92get_setf_expansion(2, v3f, v2env);
   return value0;
L5:;
   {
    cl_object v4store;
    v4store = cl_gensym(0);
    T0 = ecl_list1(v4store);
    T1 = cl_list(3, ECL_SYM("SETQ",754), v1form, v4store);
    cl_env_copy->nvalues = 5;
    cl_env_copy->values[4] = v1form;
    cl_env_copy->values[3] = T1;
    cl_env_copy->values[2] = T0;
    cl_env_copy->values[1] = ECL_NIL;
    cl_env_copy->values[0] = ECL_NIL;
    return cl_env_copy->values[0];
   }
L3:;
   if (!(ECL_CONSP(v1form))){
    goto L12;
   }
   T0 = ecl_car(v1form);
   if (ECL_SYMBOLP(T0)) {
    goto L10;
   }
   goto L11;
L12:;
L11:;
   value0 = cl_error(2, VV[9], v1form);
   return value0;
L10:;
   T0 = ecl_car(v1form);
   v3f = si_get_sysprop(T0, ECL_SYM("SETF-METHOD",1165));
   if (Null(v3f)){
    goto L14;
   }
   value0 = ecl_function_dispatch(cl_env_copy,v3f)(2, v1form, v2env);
   return value0;
L14:;
   v3f = cl_macroexpand_1(2, v1form, v2env);
   if (Null(v3f)){
    goto L17;
   }
   if (ecl_equal(v3f,v1form)) {
    goto L17;
   }
   value0 = L92get_setf_expansion(2, v3f, v2env);
   return value0;
L17:;
   T0 = ecl_car(v1form);
   T1 = ecl_cdr(v1form);
   value0 = L87do_setf_method_expansion(3, T0, ECL_NIL, T1);
   return value0;
  }
 }
}
/* local function LAMBDA38                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC93__lambda38(cl_object v1y, cl_object v2x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("RPLACA",735), v2x, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T0, v1y);
 return value0;
}
static cl_object LC93__lambda38_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[11]);
 {
  return LC93__lambda38(v3y, v4x);
 }
}
/* local function LAMBDA40                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC94__lambda40(cl_object v1y, cl_object v2x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("RPLACD",736), v2x, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T0, v1y);
 return value0;
}
static cl_object LC94__lambda40_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[12]);
 {
  return LC94__lambda40(v3y, v4x);
 }
}
/* local function LAMBDA42                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC95__lambda42(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAR",182), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC95__lambda42_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[13]);
 {
  return LC95__lambda42(v3y, v4x);
 }
}
/* local function LAMBDA44                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC96__lambda44(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAR",182), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC96__lambda44_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[14]);
 {
  return LC96__lambda44(v3y, v4x);
 }
}
/* local function LAMBDA46                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC97__lambda46(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDR",200), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC97__lambda46_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[15]);
 {
  return LC97__lambda46(v3y, v4x);
 }
}
/* local function LAMBDA48                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC98__lambda48(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDR",200), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC98__lambda48_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[16]);
 {
  return LC98__lambda48(v3y, v4x);
 }
}
/* local function LAMBDA50                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC99__lambda50(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAAR",173), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC99__lambda50_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[17]);
 {
  return LC99__lambda50(v3y, v4x);
 }
}
/* local function LAMBDA52                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC100__lambda52(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAAR",173), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC100__lambda52_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[18]);
 {
  return LC100__lambda52(v3y, v4x);
 }
}
/* local function LAMBDA54                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC101__lambda54(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDAR",192), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC101__lambda54_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[19]);
 {
  return LC101__lambda54(v3y, v4x);
 }
}
/* local function LAMBDA56                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC102__lambda56(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDAR",192), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC102__lambda56_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[20]);
 {
  return LC102__lambda56(v3y, v4x);
 }
}
/* local function LAMBDA58                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC103__lambda58(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CADR",180), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC103__lambda58_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[21]);
 {
  return LC103__lambda58(v3y, v4x);
 }
}
/* local function LAMBDA60                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC104__lambda60(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CADR",180), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC104__lambda60_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[22]);
 {
  return LC104__lambda60(v3y, v4x);
 }
}
/* local function LAMBDA62                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC105__lambda62(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDR",199), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC105__lambda62_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[23]);
 {
  return LC105__lambda62(v3y, v4x);
 }
}
/* local function LAMBDA64                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC106__lambda64(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDR",199), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC106__lambda64_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[24]);
 {
  return LC106__lambda64(v3y, v4x);
 }
}
/* local function LAMBDA66                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC107__lambda66(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAAAR",169), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC107__lambda66_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[25]);
 {
  return LC107__lambda66(v3y, v4x);
 }
}
/* local function LAMBDA68                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC108__lambda68(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAAAR",169), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC108__lambda68_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[26]);
 {
  return LC108__lambda68(v3y, v4x);
 }
}
/* local function LAMBDA70                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC109__lambda70(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDAAR",188), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC109__lambda70_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[27]);
 {
  return LC109__lambda70(v3y, v4x);
 }
}
/* local function LAMBDA72                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC110__lambda72(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDAAR",188), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC110__lambda72_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[28]);
 {
  return LC110__lambda72(v3y, v4x);
 }
}
/* local function LAMBDA74                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC111__lambda74(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CADAR",176), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC111__lambda74_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[29]);
 {
  return LC111__lambda74(v3y, v4x);
 }
}
/* local function LAMBDA76                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC112__lambda76(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CADAR",176), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC112__lambda76_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[30]);
 {
  return LC112__lambda76(v3y, v4x);
 }
}
/* local function LAMBDA78                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC113__lambda78(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDAR",195), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC113__lambda78_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[31]);
 {
  return LC113__lambda78(v3y, v4x);
 }
}
/* local function LAMBDA80                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC114__lambda80(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDAR",195), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC114__lambda80_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[32]);
 {
  return LC114__lambda80(v3y, v4x);
 }
}
/* local function LAMBDA82                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC115__lambda82(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAADR",172), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC115__lambda82_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[33]);
 {
  return LC115__lambda82(v3y, v4x);
 }
}
/* local function LAMBDA84                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC116__lambda84(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CAADR",172), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC116__lambda84_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[34]);
 {
  return LC116__lambda84(v3y, v4x);
 }
}
/* local function LAMBDA86                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC117__lambda86(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDADR",191), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC117__lambda86_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[35]);
 {
  return LC117__lambda86(v3y, v4x);
 }
}
/* local function LAMBDA88                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC118__lambda88(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDADR",191), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC118__lambda88_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[36]);
 {
  return LC118__lambda88(v3y, v4x);
 }
}
/* local function LAMBDA90                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC119__lambda90(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CADDR",179), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC119__lambda90_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[37]);
 {
  return LC119__lambda90(v3y, v4x);
 }
}
/* local function LAMBDA92                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC120__lambda92(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CADDR",179), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC120__lambda92_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[38]);
 {
  return LC120__lambda92(v3y, v4x);
 }
}
/* local function LAMBDA94                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC121__lambda94(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDDR",198), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC121__lambda94_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[39]);
 {
  return LC121__lambda94(v3y, v4x);
 }
}
/* local function LAMBDA96                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC122__lambda96(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDDR",198), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACD",736), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC122__lambda96_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[40]);
 {
  return LC122__lambda96(v3y, v4x);
 }
}
/* local function LAMBDA98                                                    */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC123__lambda98(cl_object v1y, cl_object v2x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("RPLACA",735), v2x, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T0, v1y);
 return value0;
}
static cl_object LC123__lambda98_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[41]);
 {
  return LC123__lambda98(v3y, v4x);
 }
}
/* local function LAMBDA100                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC124__lambda100(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDR",200), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC124__lambda100_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[42]);
 {
  return LC124__lambda100(v3y, v4x);
 }
}
/* local function LAMBDA102                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC125__lambda102(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDR",199), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC125__lambda102_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[43]);
 {
  return LC125__lambda102(v3y, v4x);
 }
}
/* local function LAMBDA104                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC126__lambda104(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDDR",198), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC126__lambda104_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[44]);
 {
  return LC126__lambda104(v3y, v4x);
 }
}
/* local function LAMBDA106                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC127__lambda106(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(2, ECL_SYM("CDDDDR",197), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC127__lambda106_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[45]);
 {
  return LC127__lambda106(v3y, v4x);
 }
}
/* local function LAMBDA108                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC128__lambda108(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("NTHCDR",606), ecl_make_int8_t(5), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC128__lambda108_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[46]);
 {
  return LC128__lambda108(v3y, v4x);
 }
}
/* local function LAMBDA110                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC129__lambda110(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("NTHCDR",606), ecl_make_int8_t(6), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC129__lambda110_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[47]);
 {
  return LC129__lambda110(v3y, v4x);
 }
}
/* local function LAMBDA112                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC130__lambda112(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("NTHCDR",606), ecl_make_int8_t(7), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC130__lambda112_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[48]);
 {
  return LC130__lambda112(v3y, v4x);
 }
}
/* local function LAMBDA114                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC131__lambda114(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("NTHCDR",606), ecl_make_int8_t(8), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC131__lambda114_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[49]);
 {
  return LC131__lambda114(v3y, v4x);
 }
}
/* local function LAMBDA116                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC132__lambda116(cl_object v1y, cl_object v2x)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("NTHCDR",606), ecl_make_int8_t(9), v2x);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1y);
 return value0;
}
static cl_object LC132__lambda116_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[50]);
 {
  return LC132__lambda116(v3y, v4x);
 }
}
/* local function LAMBDA118                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC133__lambda118(cl_object v1y, cl_object v2x)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("RPLACD",736), v2x, v1y);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T0, v1y);
 return value0;
}
static cl_object LC133__lambda118_va(cl_narg narg, cl_object v3y, cl_object v4x, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[51]);
 {
  return LC133__lambda118(v3y, v4x);
 }
}
/* local function LAMBDA125                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC134__lambda125(cl_narg narg, cl_object v1v, cl_object v2s, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<2)) FEwrong_num_arguments(VV[52]);
 if (ecl_unlikely(narg>3)) FEwrong_num_arguments(VV[52]);
 {
  cl_object v3env;
  va_list args; va_start(args,v2s);
  {
   int i = 2;
   if (i >= narg) {
    v3env = ECL_NIL;
   } else {
    i++;
    v3env = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = cl_list(4, ECL_SYM("FSET",1090), v2s, v1v, ECL_T);
  return value0;
 }
}
/* local function LAMBDA129                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC135__lambda129(cl_narg narg, cl_object v1v, cl_object v2s, cl_object v3p, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[53]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[53]);
 {
  cl_object v4d;
  va_list args; va_start(args,v3p);
  {
   int i = 3;
   if (i >= narg) {
    v4d = ECL_NIL;
   } else {
    i++;
    v4d = va_arg(args,cl_object);
   }
  }
  va_end(args);
  if (Null(v4d)){
   goto L2;
  }
  T0 = cl_list(4, ECL_SYM("PUTPROP",1151), v2s, v1v, v3p);
  value0 = cl_list(3, ECL_SYM("PROGN",674), v4d, T0);
  return value0;
L2:;
  value0 = cl_list(4, ECL_SYM("PUTPROP",1151), v2s, v1v, v3p);
  return value0;
 }
}
/* local function LAMBDA132                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC136__lambda132(cl_object v1v, cl_object v2n, cl_object v3l)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_list(3, ECL_SYM("NTHCDR",606), v2n, v3l);
 T1 = cl_list(3, ECL_SYM("RPLACA",735), T0, v1v);
 value0 = cl_list(3, ECL_SYM("PROGN",674), T1, v1v);
 return value0;
}
static cl_object LC136__lambda132_va(cl_narg narg, cl_object v4v, cl_object v5n, cl_object v6l, ...)
{
 if (ecl_unlikely(narg!=3)) FEwrong_num_arguments(VV[54]);
 {
  return LC136__lambda132(v4v, v5n, v6l);
 }
}
/* local function LAMBDA140                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC137__lambda140(cl_narg narg, cl_object v1v, cl_object v2k, cl_object v3h, ...)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[55]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[55]);
 {
  cl_object v4d;
  va_list args; va_start(args,v3h);
  {
   int i = 3;
   if (i >= narg) {
    v4d = ECL_NIL;
   } else {
    i++;
    v4d = va_arg(args,cl_object);
   }
  }
  va_end(args);
  value0 = cl_list(4, ECL_SYM("HASH-SET",1098), v2k, v3h, v1v);
  return value0;
 }
}
/* local function LAMBDA143                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC138__lambda143(cl_object v1function, cl_object v2fname)
{
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 value0 = cl_list(4, ECL_SYM("PUT-SYSPROP",1150), v2fname, VV[57], v1function);
 return value0;
}
static cl_object LC138__lambda143_va(cl_narg narg, cl_object v3function, cl_object v4fname, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[56]);
 {
  return LC138__lambda143(v3function, v4fname);
 }
}
/* local function LAMBDA149                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC139__lambda149(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4place;
  cl_object v5indicator;
  cl_object v6default;
  cl_object v7default_p;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4place = v8;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5indicator = v8;
  }
  if (Null(v3)){
   goto L16;
  }
  v6default = ecl_car(v3);
  goto L15;
L16:;
  v6default = ECL_NIL;
L15:;
  if (Null(v3)){
   goto L20;
  }
  v3 = ecl_cdr(v3);
  v7default_p = ECL_T;
  goto L18;
L20:;
  v7default_p = ECL_NIL;
  goto L18;
L18:;
  if (Null(v3)){
   goto L24;
  }
  si_dm_too_many_arguments(v1);
L24:;
  {
   cl_object v8;                                  /*  VARS                    */
   cl_object v9;                                  /*  VALS                    */
   cl_object v10;                                 /*  STORES                  */
   cl_object v11;                                 /*  STORE-FORM              */
   cl_object v12;                                 /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v4place, v2env);
   {
    v8 = value0;
    v9 = cl_env_copy->values[1];
    v10 = cl_env_copy->values[2];
    v11 = cl_env_copy->values[3];
    v12 = cl_env_copy->values[4];
   }
   {
    cl_object v13itemp;
    cl_object v14store;
    cl_object v15def;
    v13itemp = cl_gensym(0);
    v14store = cl_gensym(0);
    v15def = cl_gensym(0);
    if (Null(v7default_p)){
     goto L31;
    }
    T0 = ecl_list1(v15def);
    goto L30;
L31:;
    T0 = ECL_NIL;
L30:;
    T1 = CONS(v13itemp,T0);
    T2 = ecl_append(v8,T1);
    if (Null(v7default_p)){
     goto L35;
    }
    T3 = ecl_list1(v6default);
    goto L33;
L35:;
    T3 = ECL_NIL;
    goto L33;
L33:;
    T4 = CONS(v5indicator,T3);
    T5 = ecl_append(v9,T4);
    T6 = ecl_list1(v14store);
    T7 = ecl_car(v10);
    T8 = cl_list(4, ECL_SYM("PUT-F",1148), v12, v14store, v13itemp);
    T9 = cl_list(2, T7, T8);
    T10 = ecl_list1(T9);
    T11 = cl_list(4, ECL_SYM("LET",479), T10, v11, v14store);
    T12 = cl_list(4, ECL_SYM("GETF",414), v12, v13itemp, v6default);
    cl_env_copy->nvalues = 5;
    cl_env_copy->values[4] = T12;
    cl_env_copy->values[3] = T11;
    cl_env_copy->values[2] = T6;
    cl_env_copy->values[1] = T5;
    cl_env_copy->values[0] = T2;
    return cl_env_copy->values[0];
   }
  }
 }
}
static cl_object LC139__lambda149_va(cl_narg narg, cl_object v8, cl_object v9env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[58]);
 {
  return LC139__lambda149(v8, v9env);
 }
}
/* local function LAMBDA153                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC140__lambda153(cl_narg narg, cl_object v1sequence2, cl_object v2sequence1, cl_object v3start1, ...)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 if (ecl_unlikely(narg<3)) FEwrong_num_arguments(VV[60]);
 if (ecl_unlikely(narg>4)) FEwrong_num_arguments(VV[60]);
 {
  cl_object v4end1;
  va_list args; va_start(args,v3start1);
  {
   int i = 3;
   if (i >= narg) {
    v4end1 = ECL_NIL;
   } else {
    i++;
    v4end1 = va_arg(args,cl_object);
   }
  }
  va_end(args);
  T0 = cl_list(7, ECL_SYM("REPLACE",720), v2sequence1, v1sequence2, ECL_SYM("START1",1348), v3start1, ECL_SYM("END1",1257), v4end1);
  value0 = cl_list(3, ECL_SYM("PROGN",674), T0, v1sequence2);
  return value0;
 }
}
/* local function LAMBDA157                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC141__lambda157(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4type;
  cl_object v5place;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4type = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5place = v6;
  }
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  {
   cl_object v6;                                  /*  VARS                    */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  STORE-FORM              */
   cl_object v10;                                 /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v5place, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   T0 = ecl_car(v8);
   T1 = cl_list(3, ECL_SYM("THE",859), v4type, T0);
   T2 = ecl_car(v8);
   T3 = cl_subst(3, T1, T2, v9);
   T4 = cl_list(3, ECL_SYM("THE",859), v4type, v10);
   cl_env_copy->nvalues = 5;
   cl_env_copy->values[4] = T4;
   cl_env_copy->values[3] = T3;
   cl_env_copy->values[2] = v8;
   cl_env_copy->values[1] = v7;
   cl_env_copy->values[0] = v6;
   return cl_env_copy->values[0];
  }
 }
}
static cl_object LC141__lambda157_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[61]);
 {
  return LC141__lambda157(v6, v7env);
 }
}
/* local function LAMBDA163                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC142__lambda163(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4fn;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4fn = v5;
  }
  if (!(ECL_CONSP(v4fn))){
   goto L12;
  }
  T0 = ecl_car(v4fn);
  if ((T0)==(ECL_SYM("FUNCTION",398))) {
   goto L15;
  }
  T0 = ecl_car(v4fn);
  if (!((T0)==(ECL_SYM("QUOTE",682)))){
   goto L12;
  }
  goto L14;
L15:;
L14:;
  T0 = ecl_cadr(v4fn);
  if (!(ECL_SYMBOLP(T0))){
   goto L12;
  }
  T0 = ecl_cddr(v4fn);
  if (T0==ECL_NIL) {
   goto L9;
  }
  goto L10;
L12:;
  goto L10;
L10:;
  cl_error(2, VV[63], v4fn);
L9:;
  {
   cl_object v5;                                  /*  VARS                    */
   cl_object v6;                                  /*  VALS                    */
   cl_object v7;                                  /*  STORES                  */
   cl_object v8;                                  /*  STORE-FORM              */
   cl_object v9;                                  /*  ACCESS-FORM             */
   T0 = ecl_cadr(v4fn);
   T1 = CONS(T0,v3);
   value0 = L92get_setf_expansion(2, T1, v2env);
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
    v7 = cl_env_copy->values[2];
    v8 = cl_env_copy->values[3];
    v9 = cl_env_copy->values[4];
   }
   T0 = ecl_last(v8,1);
   T1 = ecl_car(T0);
   T2 = ecl_last(v5,1);
   T3 = ecl_car(T2);
   if (!((T1)==(T3))){
    goto L19;
   }
   T0 = ecl_car(v8);
   T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
   T2 = ecl_cdr(v8);
   T3 = cl_listX(3, ECL_SYM("APPLY",91), T1, T2);
   T4 = ecl_cadr(v4fn);
   T5 = cl_list(2, ECL_SYM("FUNCTION",398), T4);
   T6 = ecl_cdr(v9);
   T7 = cl_listX(3, ECL_SYM("APPLY",91), T5, T6);
   cl_env_copy->nvalues = 5;
   cl_env_copy->values[4] = T7;
   cl_env_copy->values[3] = T3;
   cl_env_copy->values[2] = v7;
   cl_env_copy->values[1] = v6;
   cl_env_copy->values[0] = v5;
   return cl_env_copy->values[0];
L19:;
   T0 = ecl_butlast(v8,1);
   T1 = ecl_last(T0,1);
   T2 = ecl_car(T1);
   T3 = ecl_last(v5,1);
   T4 = ecl_car(T3);
   if (!((T2)==(T4))){
    goto L21;
   }
   T0 = ecl_car(v8);
   T1 = cl_list(2, ECL_SYM("FUNCTION",398), T0);
   T2 = cl_butlast(2, v8, ecl_make_int8_t(2));
   T3 = ecl_cdr(T2);
   T4 = ecl_butlast(v8,1);
   T5 = ecl_last(T4,1);
   T6 = ecl_car(T5);
   T7 = ecl_last(v8,1);
   T8 = ecl_car(T7);
   T9 = cl_list(2, ECL_SYM("LIST",483), T8);
   T10 = cl_list(3, ECL_SYM("APPEND",90), T6, T9);
   T11 = ecl_list1(T10);
   T12 = ecl_append(T3,T11);
   T13 = cl_listX(3, ECL_SYM("APPLY",91), T1, T12);
   T14 = ecl_cadr(v4fn);
   T15 = cl_list(2, ECL_SYM("FUNCTION",398), T14);
   T16 = ecl_cdr(v9);
   T17 = cl_listX(3, ECL_SYM("APPLY",91), T15, T16);
   cl_env_copy->nvalues = 5;
   cl_env_copy->values[4] = T17;
   cl_env_copy->values[3] = T13;
   cl_env_copy->values[2] = v7;
   cl_env_copy->values[1] = v6;
   cl_env_copy->values[0] = v5;
   return cl_env_copy->values[0];
L21:;
   value0 = cl_error(2, VV[63], v4fn);
   return value0;
  }
 }
}
static cl_object LC142__lambda163_va(cl_narg narg, cl_object v5, cl_object v6env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[62]);
 {
  return LC142__lambda163(v5, v6env);
 }
}
/* local function LAMBDA168                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC143__lambda168(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4bytespec;
  cl_object v5int;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4bytespec = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5int = v6;
  }
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  {
   cl_object v6;                                  /*  TEMPS                   */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  STORE-FORM              */
   cl_object v10;                                 /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v5int, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   {
    cl_object v11btemp;
    cl_object v12store;
    cl_object v13stemp;
    v11btemp = cl_gensym(0);
    v12store = cl_gensym(0);
    v13stemp = ecl_car(v8);
    T0 = CONS(v11btemp,v6);
    T1 = CONS(v4bytespec,v7);
    T2 = ecl_list1(v12store);
    T3 = cl_list(4, ECL_SYM("DPB",320), v12store, v11btemp, v10);
    T4 = cl_list(2, v13stemp, T3);
    T5 = ecl_list1(T4);
    T6 = cl_list(4, ECL_SYM("LET",479), T5, v9, v12store);
    T7 = cl_list(3, ECL_SYM("LDB",459), v11btemp, v10);
    cl_env_copy->nvalues = 5;
    cl_env_copy->values[4] = T7;
    cl_env_copy->values[3] = T6;
    cl_env_copy->values[2] = T2;
    cl_env_copy->values[1] = T1;
    cl_env_copy->values[0] = T0;
    return cl_env_copy->values[0];
   }
  }
 }
}
static cl_object LC143__lambda168_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[64]);
 {
  return LC143__lambda168(v6, v7env);
 }
}
/* local function LAMBDA174                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC144__lambda174(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4bytespec;
  cl_object v5int;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4bytespec = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5int = v6;
  }
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  {
   cl_object v6;                                  /*  TEMPS                   */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  STORE-FORM              */
   cl_object v10;                                 /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v5int, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   {
    cl_object v11btemp;
    cl_object v12store;
    cl_object v13stemp;
    v11btemp = cl_gensym(0);
    v12store = cl_gensym(0);
    v13stemp = ecl_car(v8);
    T0 = CONS(v11btemp,v6);
    T1 = CONS(v4bytespec,v7);
    T2 = ecl_list1(v12store);
    T3 = cl_list(4, ECL_SYM("DEPOSIT-FIELD",300), v12store, v11btemp, v10);
    T4 = cl_list(2, v13stemp, T3);
    T5 = ecl_list1(T4);
    T6 = cl_list(4, ECL_SYM("LET",479), T5, v9, v12store);
    T7 = cl_list(3, ECL_SYM("MASK-FIELD",552), v11btemp, v10);
    cl_env_copy->nvalues = 5;
    cl_env_copy->values[4] = T7;
    cl_env_copy->values[3] = T6;
    cl_env_copy->values[2] = T2;
    cl_env_copy->values[1] = T1;
    cl_env_copy->values[0] = T0;
    return cl_env_copy->values[0];
   }
  }
 }
}
static cl_object LC144__lambda174_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[65]);
 {
  return LC144__lambda174(v6, v7env);
 }
}
/* function definition for TRIVIAL-SETF-FORM                                  */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object L145trivial_setf_form(cl_object v1place, cl_object v2vars, cl_object v3stores, cl_object v4store_form, cl_object v5access_form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 if (!(ECL_ATOM(v1place))){
  goto L3;
 }
 if (!(v2vars==ECL_NIL)){
  goto L3;
 }
 if (!((v5access_form)==(v1place))){
  goto L3;
 }
 {
  cl_fixnum v6;
  v6 = ecl_length(v3stores);
  if (!((v6)==((cl_fixnum)(1)))){
   goto L3;
  }
 }
 if (!(ECL_LISTP(v4store_form))){
  goto L3;
 }
 {
  cl_fixnum v6;
  v6 = ecl_length(v4store_form);
  if (!((v6)==((cl_fixnum)(3)))){
   goto L3;
  }
 }
 {
  cl_object v6;
  v6 = _ecl_car(v4store_form);
  if (!((v6)==(ECL_SYM("SETQ",754)))){
   goto L15;
  }
  goto L12;
L15:;
  goto L13;
L13:;
  if (!((v6)==(ECL_SYM("SETF",753)))){
   goto L3;
  }
  goto L10;
L12:;
 }
L10:;
 T0 = _ecl_cadr(v4store_form);
 if (!((T0)==(v1place))){
  goto L3;
 }
 T0 = _ecl_caddr(v4store_form);
 T1 = _ecl_car(v3stores);
 value0 = ecl_make_bool((T0)==(T1));
 cl_env_copy->nvalues = 1;
 return value0;
L3:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for TRY-SIMPLER-EXPANSION                              */
/* optimize speed 3, debug 1, space 1, safety 0                               */
static cl_object L146try_simpler_expansion(cl_object v1place, cl_object v2vars, cl_object v3vals, cl_object v4stores, cl_object v5newvalue, cl_object v6store_form)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
L1:;
 if (!(ECL_CONSP(v1place))){
  goto L2;
 }
 if (!(ECL_CONSP(v6store_form))){
  goto L2;
 }
 {
  cl_fixnum v7;
  v7 = ecl_length(v1place);
  {
   cl_fixnum v8;
   v8 = ecl_length(v6store_form);
   {
    cl_fixnum v9;
    v9 = (v8)-1;
    if (!((v7)==(v9))){
     goto L2;
    }
   }
  }
 }
 {
  cl_object v7;
  cl_object v8output;
  cl_object v9v;
  {
   cl_object v10;
   v10 = v6store_form;
   if (Null(v10)){
    goto L9;
   }
   {
    cl_object v11;
    v11 = ECL_CONS_CDR(v10);
    v6store_form = v11;
    v10 = ECL_CONS_CAR(v10);
   }
L9:;
   v7 = v10;
  }
  v8output = ECL_NIL;
  v9v = ECL_NIL;
  {
   cl_object v10;
   v10 = _ecl_cdr(v1place);
   goto L20;
L19:;
   {
    cl_object v11i;
    v11i = _ecl_car(v10);
    if (ECL_CONSP(v6store_form)) {
     goto L24;
    }
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L24:;
    v9v = ECL_CONS_CAR(v6store_form);
    v6store_form = ECL_CONS_CDR(v6store_form);
    if ((v9v)==(v11i)) {
     goto L30;
    }
    {
     cl_object v12;
     v12 = v2vars;
     if (Null(v12)){
      goto L39;
     }
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v12);
      v2vars = v13;
      v12 = ECL_CONS_CAR(v12);
     }
L39:;
     T0 = v12;
    }
    if (!((v9v)==(T0))){
     goto L34;
    }
    {
     cl_object v12;
     v12 = v3vals;
     if (Null(v12)){
      goto L48;
     }
     {
      cl_object v13;
      v13 = ECL_CONS_CDR(v12);
      v3vals = v13;
      v12 = ECL_CONS_CAR(v12);
     }
L48:;
     T0 = v12;
    }
    if ((T0)==(v11i)) {
     goto L30;
    }
    goto L31;
L34:;
    goto L31;
L31:;
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 1;
    return value0;
L30:;
    v8output = CONS(v11i,v8output);
   }
   v10 = _ecl_cdr(v10);
L20:;
   if (Null(v10)){
    goto L58;
   }
   goto L19;
L58:;
   T0 = _ecl_car(v4stores);
   T1 = _ecl_car(v6store_form);
   if (!((T0)==(T1))){
    goto L60;
   }
   T0 = CONS(v5newvalue,v8output);
   T1 = cl_nreverse(T0);
   value0 = CONS(v7,T1);
   cl_env_copy->nvalues = 1;
   return value0;
L60:;
   value0 = ECL_NIL;
   cl_env_copy->nvalues = 1;
   return value0;
  }
 }
L2:;
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
}
/* function definition for SETF-EXPAND-1                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L147setf_expand_1(cl_object v1place, cl_object v2newvalue, cl_object v3env)
{
 cl_object T0, T1, T2;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v4;                                   /*  VARS                    */
  cl_object v5;                                   /*  VALS                    */
  cl_object v6;                                   /*  STORES                  */
  cl_object v7;                                   /*  STORE-FORM              */
  cl_object v8;                                   /*  ACCESS-FORM             */
  value0 = L92get_setf_expansion(2, v1place, v3env);
  {
   v4 = value0;
   v5 = cl_env_copy->values[1];
   v6 = cl_env_copy->values[2];
   v7 = cl_env_copy->values[3];
   v8 = cl_env_copy->values[4];
  }
  if (Null(L145trivial_setf_form(v1place, v4, v6, v7, v8))){
   goto L3;
  }
  value0 = cl_list(3, ECL_SYM("SETQ",754), v1place, v2newvalue);
  return value0;
L3:;
  {
   cl_object v9;
   v9 = L146try_simpler_expansion(v1place, v4, v5, v6, v2newvalue, v7);
   if (Null(v9)){
    goto L6;
   }
   value0 = v9;
   cl_env_copy->nvalues = 1;
   return value0;
L6:;
   T0 = (ECL_SYM("LIST",483)->symbol.gfdef);
   T1 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(3, T0, v4, v5) /*  MAPCAR */;
   T2 = cl_list(4, ECL_SYM("MULTIPLE-VALUE-BIND",574), v6, v2newvalue, v7);
   value0 = cl_list(3, ECL_SYM("LET*",480), T1, T2);
   return value0;
  }
 }
}
/* function definition for SETF-EXPAND                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object L148setf_expand(cl_object v1l, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (!(ecl_endp(v1l))){
  goto L2;
 }
 value0 = ECL_NIL;
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 T0 = ecl_cdr(v1l);
 if (!(ecl_endp(T0))){
  goto L4;
 }
 value0 = cl_error(2, VV[73], v1l);
 return value0;
L4:;
 T0 = ecl_car(v1l);
 T1 = ecl_cadr(v1l);
 T2 = L147setf_expand_1(T0, T1, v2env);
 T3 = ecl_cddr(v1l);
 T4 = L148setf_expand(T3, v2env);
 value0 = CONS(T2,T4);
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function SETF                                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC149setf(cl_object v1, cl_object v2env)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  if (!(ecl_endp(v3))){
   goto L3;
  }
  value0 = ECL_NIL;
  cl_env_copy->nvalues = 1;
  return value0;
L3:;
  T0 = ecl_cdr(v3);
  if (!(ecl_endp(T0))){
   goto L5;
  }
  value0 = cl_error(2, VV[73], v3);
  return value0;
L5:;
  T0 = ecl_cddr(v3);
  if (!(ecl_endp(T0))){
   goto L7;
  }
  T0 = ecl_car(v3);
  T1 = ecl_cadr(v3);
  value0 = L147setf_expand_1(T0, T1, v2env);
  return value0;
L7:;
  T0 = L148setf_expand(v3, v2env);
  value0 = CONS(ECL_SYM("PROGN",674),T0);
  cl_env_copy->nvalues = 1;
  return value0;
 }
}
static cl_object LC149setf_va(cl_narg narg, cl_object v4, cl_object v5env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[74]);
 {
  return LC149setf(v4, v5env);
 }
}
/* local function WITH-SETF-EXPANSIONS                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC150with_setf_expansions(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6pairs;
  cl_object v7stores;
  cl_object v8store_forms;
  cl_object v9access_forms;
  cl_object v10;
  cl_object v11;
  cl_object v12args;
  cl_object v13env;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v14;
   v14 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v14;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v14;
   v14 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6pairs = v14;
  }
  if (!(v5==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v1);
L17:;
  {
   cl_object v14;
   v14 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7stores = v14;
  }
  if (!(v5==ECL_NIL)){
   goto L23;
  }
  si_dm_too_few_arguments(v1);
L23:;
  {
   cl_object v14;
   v14 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v8store_forms = v14;
  }
  if (!(v5==ECL_NIL)){
   goto L29;
  }
  si_dm_too_few_arguments(v1);
L29:;
  {
   cl_object v14;
   v14 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v9access_forms = v14;
  }
  if (!(v3==ECL_NIL)){
   goto L35;
  }
  si_dm_too_few_arguments(v1);
L35:;
  {
   cl_object v14;
   v14 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v10 = v14;
  }
  v11 = v10;
  if (!(v11==ECL_NIL)){
   goto L42;
  }
  si_dm_too_few_arguments(v1);
L42:;
  {
   cl_object v14;
   v14 = ecl_car(v11);
   v11 = ecl_cdr(v11);
   v12args = v14;
  }
  if (Null(v11)){
   goto L48;
  }
  {
   cl_object v14;
   v14 = ecl_car(v11);
   v11 = ecl_cdr(v11);
   v13env = v14;
   goto L47;
  }
L48:;
  v13env = ECL_NIL;
L47:;
  if (Null(v11)){
   goto L53;
  }
  si_dm_too_many_arguments(v1);
L53:;
  if (Null(v5)){
   goto L55;
  }
  si_dm_too_many_arguments(v1);
L55:;
  T0 = cl_list(4, v6pairs, v7stores, v8store_forms, v9access_forms);
  T1 = cl_list(3, ECL_SYM("GET-SETF-EXPANSION",412), VV[78], v13env);
  T2 = cl_list(2, ECL_SYM("MULTIPLE-VALUE-LIST",576), T1);
  T3 = cl_list(3, ECL_SYM("LAMBDA",454), VV[77], T2);
  T4 = cl_list(2, ECL_SYM("REVERSE",730), v12args);
  T5 = cl_list(3, ECL_SYM("MAPCAR",547), T3, T4);
  T6 = cl_listX(4, ECL_SYM("REDUCE",709), VV[76], T5, VV[79]);
  value0 = cl_listX(4, ECL_SYM("DESTRUCTURING-BIND",302), T0, T6, v3);
  return value0;
 }
}
static cl_object LC150with_setf_expansions_va(cl_narg narg, cl_object v14, cl_object v15, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[75]);
 {
  return LC150with_setf_expansions(v14, v15);
 }
}
/* local function PSETF                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC154psetf(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2env,env0);                  /*  ENV                     */
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  {
   cl_object v4;                                  /*  PLACES                  */
   cl_object v5;                                  /*  FORMS                   */
   {
    cl_object v6args;
    cl_object v7places;
    cl_object v8forms;
    v6args = v3;
    v7places = ECL_NIL;
    v8forms = ECL_NIL;
    goto L8;
L7:;
    T0 = ecl_cdr(v6args);
    if (!(ecl_endp(T0))){
     goto L10;
    }
    cl_error(2, VV[81], v6args);
L10:;
    T0 = ecl_car(v6args);
    v7places = CONS(T0,v7places);
    T0 = ecl_cadr(v6args);
    v8forms = CONS(T0,v8forms);
    v6args = ecl_cddr(v6args);
L8:;
    if (ecl_endp(v6args)) {
     goto L18;
    }
    goto L7;
L18:;
    T0 = cl_nreverse(v7places);
    T1 = cl_nreverse(v8forms);
    cl_env_copy->nvalues = 2;
    cl_env_copy->values[1] = T1;
    cl_env_copy->values[0] = T0;
    value0 = cl_env_copy->values[0];
   }
   {
    v4 = value0;
    v5 = cl_env_copy->values[1];
   }
   {
    cl_object v6;
    cl_object v7;
    cl_object v8pairs;
    cl_object v9stores;
    cl_object v10access_forms;
    {
     cl_object v11;
     v11 = ecl_make_cfun_va((cl_objectfn)LC151__lambda268_va,ECL_NIL,Cblock,2);
     T0 = v11;
    }
    {
     cl_object v11;
     {
      cl_object v12;
      v12 = ecl_make_cclosure_va((cl_objectfn)LC152__lambda286,env0,Cblock,1);
      v11 = v12;
     }
     {
      cl_object v12;
      cl_object v13;
      cl_object v14;
      {
       cl_object v15;
       v15 = cl_reverse(v4);
       if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v12 = v15;
      }
      v13 = ECL_NIL;
      v14 = v12;
      {
       cl_object v15;
       cl_object v16;
       v15 = ecl_list1(ECL_NIL);
       v16 = v15;
L31:;
       if (!(ecl_endp(v14))){
        goto L33;
       }
       goto L32;
L33:;
       v13 = ECL_CONS_CAR(v14);
       {
        cl_object v17;
        v17 = ECL_CONS_CDR(v14);
        if (ecl_unlikely(!ECL_LISTP(v17))) FEtype_error_list(v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        v14 = v17;
       }
       {
        cl_object v17;
        v17 = v16;
        if (ecl_unlikely(ECL_ATOM(v17))) FEtype_error_cons(v17);
        value0 = ECL_NIL;
        cl_env_copy->nvalues = 0;
        T2 = v17;
       }
       T3 = ecl_function_dispatch(cl_env_copy,v11)(1, v13);
       v16 = ecl_list1(T3);
       (ECL_CONS_CDR(T2)=v16,T2);
       goto L31;
L32:;
       T1 = ecl_cdr(v15);
       goto L22;
      }
     }
    }
L22:;
    v6 = cl_reduce(4, T0, T1, VV[89], VV[90]);
    v7 = v6;
    if (!(v7==ECL_NIL)){
     goto L51;
    }
    si_dm_too_few_arguments(v6);
L51:;
    {
     cl_object v11;
     v11 = ecl_car(v7);
     v7 = ecl_cdr(v7);
     v8pairs = v11;
    }
    if (!(v7==ECL_NIL)){
     goto L57;
    }
    si_dm_too_few_arguments(v6);
L57:;
    {
     cl_object v11;
     v11 = ecl_car(v7);
     v7 = ecl_cdr(v7);
     v9stores = v11;
    }
    if (!(v7==ECL_NIL)){
     goto L62;
    }
    si_dm_too_few_arguments(v6);
L62:;
    {
     cl_object v11;
     v11 = ecl_car(v7);
     v7 = ecl_cdr(v7);
     T0 = v11;
    }
    lex0[0] = T0;                                 /*  STORE-FORMS             */
    if (!(v7==ECL_NIL)){
     goto L69;
    }
    si_dm_too_few_arguments(v6);
L69:;
    {
     cl_object v11;
     v11 = ecl_car(v7);
     v7 = ecl_cdr(v7);
     v10access_forms = v11;
    }
    if (Null(v7)){
     goto L74;
    }
    si_dm_too_many_arguments(v6);
L74:;
    T0 = LC153thunk(lex0, v8pairs, v9stores, v5);
    value0 = cl_listX(3, ECL_SYM("PROG1",672), ECL_NIL, T0);
    return value0;
   }
  }
 }
}
static cl_object LC154psetf_va(cl_narg narg, cl_object v4, cl_object v5env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[92]);
 {
  return LC154psetf(v4, v5env);
 }
}
/* local function WITH-EXPANSION-SETTER                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC155with_expansion_setter(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4;
  cl_object v5;
  cl_object v6name;
  cl_object v7store_forms;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4 = v8;
  }
  v5 = v4;
  if (!(v5==ECL_NIL)){
   goto L11;
  }
  si_dm_too_few_arguments(v1);
L11:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v6name = v8;
  }
  if (!(v5==ECL_NIL)){
   goto L17;
  }
  si_dm_too_few_arguments(v1);
L17:;
  {
   cl_object v8;
   v8 = ecl_car(v5);
   v5 = ecl_cdr(v5);
   v7store_forms = v8;
  }
  if (Null(v5)){
   goto L22;
  }
  si_dm_too_many_arguments(v1);
L22:;
  T0 = CONS(v6name,VV[99]);
  T1 = cl_list(5, ECL_SYM("LIST*",484), VV[96], VV[97], VV[98], T0);
  T2 = cl_list(2, ECL_SYM("LIST",483), T1);
  T3 = cl_list(4, ECL_SYM("IF",950), VV[95], T2, v7store_forms);
  T4 = cl_list(3, v6name, VV[94], T3);
  T5 = ecl_list1(T4);
  value0 = cl_listX(3, ECL_SYM("LABELS",453), T5, v3);
  return value0;
 }
}
static cl_object LC155with_expansion_setter_va(cl_narg narg, cl_object v8, cl_object v9, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[93]);
 {
  return LC155with_expansion_setter(v8, v9);
 }
}
/* local function SHIFTF                                                      */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC159shiftf(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2env,env0);                  /*  ENV                     */
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6pairs;
   cl_object v7stores;
   cl_object v8access_forms;
   {
    cl_object v9;
    v9 = ecl_make_cfun_va((cl_objectfn)LC156__lambda324_va,ECL_NIL,Cblock,2);
    T0 = v9;
   }
   {
    cl_object v9;
    {
     cl_object v10;
     v10 = ecl_make_cclosure_va((cl_objectfn)LC157__lambda342,env0,Cblock,1);
     v9 = v10;
    }
    {
     cl_object v10;
     cl_object v11;
     cl_object v12;
     {
      cl_object v13;
      T2 = ecl_butlast(v3,1);
      v13 = cl_reverse(T2);
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v13;
     }
     v11 = ECL_NIL;
     v12 = v10;
     {
      cl_object v13;
      cl_object v14;
      v13 = ecl_list1(ECL_NIL);
      v14 = v13;
L13:;
      if (!(ecl_endp(v12))){
       goto L15;
      }
      goto L14;
L15:;
      v11 = ECL_CONS_CAR(v12);
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v12);
       if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v12 = v15;
      }
      {
       cl_object v15;
       v15 = v14;
       if (ecl_unlikely(ECL_ATOM(v15))) FEtype_error_cons(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T2 = v15;
      }
      T3 = ecl_function_dispatch(cl_env_copy,v9)(1, v11);
      v14 = ecl_list1(T3);
      (ECL_CONS_CDR(T2)=v14,T2);
      goto L13;
L14:;
      T1 = ecl_cdr(v13);
      goto L4;
     }
    }
   }
L4:;
   v4 = cl_reduce(4, T0, T1, VV[89], VV[90]);
   v5 = v4;
   if (!(v5==ECL_NIL)){
    goto L33;
   }
   si_dm_too_few_arguments(v4);
L33:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v6pairs = v9;
   }
   if (!(v5==ECL_NIL)){
    goto L39;
   }
   si_dm_too_few_arguments(v4);
L39:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v7stores = v9;
   }
   if (!(v5==ECL_NIL)){
    goto L44;
   }
   si_dm_too_few_arguments(v4);
L44:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    T0 = v9;
   }
   lex0[0] = T0;                                  /*  STORE-FORMS             */
   if (!(v5==ECL_NIL)){
    goto L51;
   }
   si_dm_too_few_arguments(v4);
L51:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v8access_forms = v9;
   }
   if (Null(v5)){
    goto L56;
   }
   si_dm_too_many_arguments(v4);
L56:;
   T0 = (ECL_SYM("APPEND",90)->symbol.gfdef);
   T1 = cl_reduce(2, T0, v6pairs);
   T2 = ecl_car(v8access_forms);
   T4 = ecl_cdr(v8access_forms);
   T5 = ecl_last(v3,1);
   T6 = ecl_append(T4,T5);
   T3 = LC158thunk(lex0, v7stores, T6);
   T4 = cl_listX(3, ECL_SYM("MULTIPLE-VALUE-PROG1",577), T2, T3);
   value0 = cl_list(3, ECL_SYM("LET*",480), T1, T4);
   return value0;
  }
 }
}
static cl_object LC159shiftf_va(cl_narg narg, cl_object v9, cl_object v10env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[103]);
 {
  return LC159shiftf(v9, v10env);
 }
}
/* local function ROTATEF                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC163rotatef(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 volatile cl_object lex0[1];
 cl_object env0 = ECL_NIL;
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 env0 = ECL_NIL;
 CLV0 = env0 = CONS(v2env,env0);                  /*  ENV                     */
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6pairs;
   cl_object v7stores;
   cl_object v8access_forms;
   {
    cl_object v9;
    v9 = ecl_make_cfun_va((cl_objectfn)LC160__lambda366_va,ECL_NIL,Cblock,2);
    T0 = v9;
   }
   {
    cl_object v9;
    {
     cl_object v10;
     v10 = ecl_make_cclosure_va((cl_objectfn)LC161__lambda384,env0,Cblock,1);
     v9 = v10;
    }
    {
     cl_object v10;
     cl_object v11;
     cl_object v12;
     {
      cl_object v13;
      v13 = cl_reverse(v3);
      if (ecl_unlikely(!ECL_LISTP(v13))) FEtype_error_list(v13);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v10 = v13;
     }
     v11 = ECL_NIL;
     v12 = v10;
     {
      cl_object v13;
      cl_object v14;
      v13 = ecl_list1(ECL_NIL);
      v14 = v13;
L13:;
      if (!(ecl_endp(v12))){
       goto L15;
      }
      goto L14;
L15:;
      v11 = ECL_CONS_CAR(v12);
      {
       cl_object v15;
       v15 = ECL_CONS_CDR(v12);
       if (ecl_unlikely(!ECL_LISTP(v15))) FEtype_error_list(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       v12 = v15;
      }
      {
       cl_object v15;
       v15 = v14;
       if (ecl_unlikely(ECL_ATOM(v15))) FEtype_error_cons(v15);
       value0 = ECL_NIL;
       cl_env_copy->nvalues = 0;
       T2 = v15;
      }
      T3 = ecl_function_dispatch(cl_env_copy,v9)(1, v11);
      v14 = ecl_list1(T3);
      (ECL_CONS_CDR(T2)=v14,T2);
      goto L13;
L14:;
      T1 = ecl_cdr(v13);
      goto L4;
     }
    }
   }
L4:;
   v4 = cl_reduce(4, T0, T1, VV[89], VV[90]);
   v5 = v4;
   if (!(v5==ECL_NIL)){
    goto L33;
   }
   si_dm_too_few_arguments(v4);
L33:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v6pairs = v9;
   }
   if (!(v5==ECL_NIL)){
    goto L39;
   }
   si_dm_too_few_arguments(v4);
L39:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v7stores = v9;
   }
   if (!(v5==ECL_NIL)){
    goto L44;
   }
   si_dm_too_few_arguments(v4);
L44:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    T0 = v9;
   }
   lex0[0] = T0;                                  /*  STORE-FORMS             */
   if (!(v5==ECL_NIL)){
    goto L51;
   }
   si_dm_too_few_arguments(v4);
L51:;
   {
    cl_object v9;
    v9 = ecl_car(v5);
    v5 = ecl_cdr(v5);
    v8access_forms = v9;
   }
   if (Null(v5)){
    goto L56;
   }
   si_dm_too_many_arguments(v4);
L56:;
   T0 = (ECL_SYM("APPEND",90)->symbol.gfdef);
   T1 = cl_reduce(2, T0, v6pairs);
   T3 = ecl_cdr(v8access_forms);
   T4 = ecl_car(v8access_forms);
   T5 = ecl_list1(T4);
   T6 = ecl_append(T3,T5);
   T2 = LC162thunk(lex0, v7stores, T6);
   T3 = ecl_append(T2,VV[106]);
   value0 = cl_listX(3, ECL_SYM("LET*",480), T1, T3);
   return value0;
  }
 }
}
static cl_object LC163rotatef_va(cl_narg narg, cl_object v9, cl_object v10env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[107]);
 {
  return LC163rotatef(v9, v10env);
 }
}
/* local function DEFINE-MODIFY-MACRO                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC164define_modify_macro(cl_object v1, cl_object v2)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15, T16, T17, T18, T19, T20, T21, T22;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4name;
  cl_object v5lambdalist;
  cl_object v6function;
  cl_object v7docstring;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4name = v8;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5lambdalist = v8;
  }
  if (!(v3==ECL_NIL)){
   goto L16;
  }
  si_dm_too_few_arguments(v1);
L16:;
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v6function = v8;
  }
  if (Null(v3)){
   goto L22;
  }
  {
   cl_object v8;
   v8 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v7docstring = v8;
   goto L21;
  }
L22:;
  v7docstring = ECL_NIL;
L21:;
  if (Null(v3)){
   goto L27;
  }
  si_dm_too_many_arguments(v1);
L27:;
  {
   cl_object v8varlist;
   cl_object v9restvar;
   v8varlist = ECL_NIL;
   v9restvar = ECL_NIL;
   {
    cl_object v10lambdalistr;
    cl_object v11next;
    v10lambdalistr = v5lambdalist;
    v11next = ECL_NIL;
    goto L36;
L35:;
    v11next = ecl_car(v10lambdalistr);
    {
     cl_object v12;
     v12 = ecl_make_bool((v11next)==(ECL_SYM("&OPTIONAL",13)));
     if (Null(v12)){
      goto L42;
     }
     goto L40;
L42:;
     if (!((v11next)==(ECL_SYM("&REST",14)))){
      goto L44;
     }
     T0 = ecl_cadr(v10lambdalistr);
     if (!(ECL_SYMBOLP(T0))){
      goto L47;
     }
     v9restvar = ecl_cadr(v10lambdalistr);
     goto L46;
L47:;
     T0 = ecl_cadr(v10lambdalistr);
     cl_error(3, VV[108], v4name, T0);
L46:;
     T0 = ecl_cddr(v10lambdalistr);
     if (!(T0==ECL_NIL)){
      goto L50;
     }
     goto L31;
L50:;
     cl_error(2, VV[109], v10lambdalistr);
     goto L40;
L44:;
     if ((v11next)==(ECL_SYM("&KEY",12))) {
      goto L54;
     }
     if ((v11next)==(ECL_SYM("&ALLOW-OTHER-KEYS",8))) {
      goto L54;
     }
     if (!((v11next)==(ECL_SYM("&AUX",9)))){
      goto L52;
     }
     goto L53;
L54:;
L53:;
     cl_error(2, VV[110], v11next);
     goto L40;
L52:;
     if (!(ECL_SYMBOLP(v11next))){
      goto L57;
     }
     v8varlist = CONS(v11next,v8varlist);
     goto L40;
L57:;
     if (!(ECL_LISTP(v11next))){
      goto L60;
     }
     T0 = ecl_car(v11next);
     if (!(ECL_SYMBOLP(T0))){
      goto L60;
     }
     T0 = ecl_car(v11next);
     v8varlist = CONS(T0,v8varlist);
     goto L40;
L60:;
     cl_error(2, VV[111], v11next);
    }
L40:;
    v10lambdalistr = ecl_cdr(v10lambdalistr);
L36:;
    if (v10lambdalistr==ECL_NIL) {
     goto L66;
    }
    goto L35;
L66:;
   }
L31:;
   v8varlist = cl_nreverse(v8varlist);
   T0 = cl_listX(4, ECL_SYM("&ENVIRONMENT",11), VV[112], VV[113], v5lambdalist);
   if (Null(v7docstring)){
    goto L72;
   }
   T1 = ecl_list1(v7docstring);
   goto L70;
L72:;
   T1 = ECL_NIL;
   goto L70;
L70:;
   T2 = ecl_list1(v9restvar);
   T3 = ecl_append(v8varlist,T2);
   T4 = CONS(ECL_SYM("LIST*",484),T3);
   T5 = cl_list(3, ECL_SYM("MAPCAR",547), VV[118], T4);
   T6 = cl_list(2, VV[117], T5);
   T7 = ecl_list1(T6);
   T8 = cl_list(2, ECL_SYM("QUOTE",682), v6function);
   T9 = cl_listX(3, ECL_SYM("LIST*",484), T8, VV[120]);
   T10 = cl_listX(3, ECL_SYM("SUBST",834), T9, VV[121]);
   T11 = cl_list(2, ECL_SYM("QUOTE",682), v6function);
   T12 = cl_listX(3, ECL_SYM("LIST*",484), T11, VV[120]);
   T13 = cl_list(3, ECL_SYM("LIST",483), VV[97], T12);
   T14 = cl_list(3, ECL_SYM("LIST*",484), T13, VV[125]);
   T15 = cl_list(3, ECL_SYM("SETQ",754), VV[124], T14);
   T16 = cl_list(3, VV[123], T15, VV[126]);
   T17 = cl_list(3, ECL_SYM("DO",309), VV[122], T16);
   T18 = cl_list(4, ECL_SYM("IF",950), VV[119], T10, T17);
   T19 = cl_list(3, ECL_SYM("LET",479), T7, T18);
   T20 = cl_list(4, ECL_SYM("MULTIPLE-VALUE-BIND",574), VV[115], VV[116], T19);
   T21 = cl_list(2, VV[114], T20);
   T22 = ecl_append(T1,T21);
   value0 = cl_listX(4, ECL_SYM("DEFMACRO",285), v4name, T0, T22);
   return value0;
  }
 }
}
static cl_object LC164define_modify_macro_va(cl_narg narg, cl_object v10, cl_object v11, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[127]);
 {
  return LC164define_modify_macro(v10, v11);
 }
}
/* local function REMF                                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC165remf(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4place;
  cl_object v5indicator;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4place = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5indicator = v6;
  }
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  {
   cl_object v6;                                  /*  VARS                    */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  STORE-FORM              */
   cl_object v10;                                 /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v4place, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   {
    cl_object v11s;
    v11s = cl_gensym(0);
    T0 = (ECL_SYM("LIST",483)->symbol.gfdef);
    T1 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(3, T0, v6, v7) /*  MAPCAR */;
    T2 = cl_list(2, v11s, v5indicator);
    T3 = ecl_list1(T2);
    T4 = ecl_append(T1,T3);
    T5 = CONS(VV[128],v6);
    T6 = cl_list(2, ECL_SYM("DECLARE",276), T5);
    T7 = ecl_car(v8);
    T8 = cl_list(2, T7, VV[129]);
    T9 = cl_list(3, ECL_SYM("REM-F",1153), v10, v11s);
    T10 = cl_list(5, ECL_SYM("MULTIPLE-VALUE-BIND",574), T8, T9, v9, VV[129]);
    value0 = cl_list(4, ECL_SYM("LET*",480), T4, T6, T10);
    return value0;
   }
  }
 }
}
static cl_object LC165remf_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[130]);
 {
  return LC165remf(v6, v7env);
 }
}
/* local function INCF                                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC167incf(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4_reference;
  cl_object v5delta;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4_reference = v6;
  }
  if (Null(v3)){
   goto L10;
  }
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5delta = v6;
   goto L9;
  }
L10:;
  v5delta = ecl_make_int8_t(1);
L9:;
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  {
   cl_object v6;                                  /*  VARS                    */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  SETTER                  */
   cl_object v10;                                 /*  GETTER                  */
   value0 = L92get_setf_expansion(2, v4_reference, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   {
    cl_object v11all_vars;
    {
     cl_object v12;
     v12 = ecl_make_cfun_va((cl_objectfn)LC166__lambda431_va,ECL_NIL,Cblock,1);
     T0 = v12;
    }
    T1 = CONS(v5delta,ECL_NIL);
    v11all_vars = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, T1) /*  MAPCAR */;
    if (!(ECL_SYMBOLP(v10))){
     goto L20;
    }
    T0 = (ECL_SYM("CAR",182)->symbol.gfdef);
    T1 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, v11all_vars) /*  MAPCAR */;
    T2 = cl_listX(3, ECL_SYM("+",16), v10, T1);
    T3 = ecl_car(v8);
    T4 = (ECL_SYM("FIRST",373)->symbol.gfdef);
    T5 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T4, v11all_vars) /*  MAPCAR */;
    T6 = CONS(VV[128],T5);
    T7 = cl_list(2, ECL_SYM("DECLARE",276), T6);
    T8 = cl_list(4, ECL_SYM("LET*",480), v11all_vars, T7, v9);
    value0 = cl_subst(3, T2, T3, T8);
    return value0;
L20:;
    {
     cl_object v12d;
     cl_object v13v;
     cl_object v14let_list;
     v12d = v6;
     v13v = v7;
     v14let_list = ECL_NIL;
     goto L29;
L28:;
     T0 = ecl_cdr(v12d);
     T1 = ecl_cdr(v13v);
     T2 = ecl_car(v12d);
     T3 = ecl_car(v13v);
     T4 = cl_list(2, T2, T3);
     v14let_list = CONS(T4,v14let_list);
     v13v = T1;
     v12d = T0;
L29:;
     if (v12d==ECL_NIL) {
      goto L35;
     }
     goto L28;
L35:;
     T0 = ecl_car(v8);
     T1 = (ECL_SYM("CAR",182)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v11all_vars) /*  MAPCAR */;
     T3 = cl_listX(3, ECL_SYM("+",16), v10, T2);
     T4 = cl_list(2, T0, T3);
     T5 = ecl_append(v11all_vars,v14let_list);
     v14let_list = CONS(T4,T5);
     T0 = cl_nreverse(v14let_list);
     T1 = (ECL_SYM("FIRST",373)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v11all_vars) /*  MAPCAR */;
     T3 = ecl_append(T2,v6);
     T4 = CONS(VV[128],T3);
     T5 = cl_list(2, ECL_SYM("DECLARE",276), T4);
     value0 = cl_list(4, ECL_SYM("LET*",480), T0, T5, v9);
     return value0;
    }
   }
  }
 }
}
static cl_object LC167incf_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[132]);
 {
  return LC167incf(v6, v7env);
 }
}
/* local function DECF                                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC169decf(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4_reference;
  cl_object v5delta;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4_reference = v6;
  }
  if (Null(v3)){
   goto L10;
  }
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5delta = v6;
   goto L9;
  }
L10:;
  v5delta = ecl_make_int8_t(1);
L9:;
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  {
   cl_object v6;                                  /*  VARS                    */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  SETTER                  */
   cl_object v10;                                 /*  GETTER                  */
   value0 = L92get_setf_expansion(2, v4_reference, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   {
    cl_object v11all_vars;
    {
     cl_object v12;
     v12 = ecl_make_cfun_va((cl_objectfn)LC168__lambda445_va,ECL_NIL,Cblock,1);
     T0 = v12;
    }
    T1 = CONS(v5delta,ECL_NIL);
    v11all_vars = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, T1) /*  MAPCAR */;
    if (!(ECL_SYMBOLP(v10))){
     goto L20;
    }
    T0 = (ECL_SYM("CAR",182)->symbol.gfdef);
    T1 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T0, v11all_vars) /*  MAPCAR */;
    T2 = cl_listX(3, ECL_SYM("-",19), v10, T1);
    T3 = ecl_car(v8);
    T4 = (ECL_SYM("FIRST",373)->symbol.gfdef);
    T5 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T4, v11all_vars) /*  MAPCAR */;
    T6 = CONS(VV[128],T5);
    T7 = cl_list(2, ECL_SYM("DECLARE",276), T6);
    T8 = cl_list(4, ECL_SYM("LET*",480), v11all_vars, T7, v9);
    value0 = cl_subst(3, T2, T3, T8);
    return value0;
L20:;
    {
     cl_object v12d;
     cl_object v13v;
     cl_object v14let_list;
     v12d = v6;
     v13v = v7;
     v14let_list = ECL_NIL;
     goto L29;
L28:;
     T0 = ecl_cdr(v12d);
     T1 = ecl_cdr(v13v);
     T2 = ecl_car(v12d);
     T3 = ecl_car(v13v);
     T4 = cl_list(2, T2, T3);
     v14let_list = CONS(T4,v14let_list);
     v13v = T1;
     v12d = T0;
L29:;
     if (v12d==ECL_NIL) {
      goto L35;
     }
     goto L28;
L35:;
     T0 = ecl_car(v8);
     T1 = (ECL_SYM("CAR",182)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v11all_vars) /*  MAPCAR */;
     T3 = cl_listX(3, ECL_SYM("-",19), v10, T2);
     T4 = cl_list(2, T0, T3);
     T5 = ecl_append(v11all_vars,v14let_list);
     v14let_list = CONS(T4,T5);
     T0 = cl_nreverse(v14let_list);
     T1 = (ECL_SYM("FIRST",373)->symbol.gfdef);
     T2 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(2, T1, v11all_vars) /*  MAPCAR */;
     T3 = ecl_append(T2,v6);
     T4 = CONS(VV[128],T3);
     T5 = cl_list(2, ECL_SYM("DECLARE",276), T4);
     value0 = cl_list(4, ECL_SYM("LET*",480), T0, T5, v9);
     return value0;
    }
   }
  }
 }
}
static cl_object LC169decf_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[134]);
 {
  return LC169decf(v6, v7env);
 }
}
/* local function PUSH                                                        */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC170push(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4item;
  cl_object v5place;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4item = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5place = v6;
  }
  if (Null(v3)){
   goto L15;
  }
  si_dm_too_many_arguments(v1);
L15:;
  {
   cl_object v6;                                  /*  VARS                    */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  STORE-FORM              */
   cl_object v10;                                 /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v5place, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   if (Null(L145trivial_setf_form(v5place, v6, v8, v9, v10))){
    goto L18;
   }
   T0 = cl_list(3, ECL_SYM("CONS",253), v4item, v5place);
   value0 = cl_list(3, ECL_SYM("SETQ",754), v5place, T0);
   return value0;
L18:;
   if (cl_constantp(2, v4item, v2env)!=ECL_NIL) {
    goto L20;
   }
   v7 = CONS(v4item,v7);
   v4item = cl_gensym(0);
   v6 = CONS(v4item,v6);
L20:;
   T0 = (ECL_SYM("LIST",483)->symbol.gfdef);
   T1 = ecl_append(v6,v8);
   T2 = cl_list(3, ECL_SYM("CONS",253), v4item, v10);
   T3 = ecl_list1(T2);
   T4 = ecl_append(v7,T3);
   T5 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(3, T0, T1, T4) /*  MAPCAR */;
   T6 = CONS(VV[128],v6);
   T7 = cl_list(2, ECL_SYM("DECLARE",276), T6);
   value0 = cl_list(4, ECL_SYM("LET*",480), T5, T7, v9);
   return value0;
  }
 }
}
static cl_object LC170push_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[135]);
 {
  return LC170push(v6, v7env);
 }
}
/* local function PUSHNEW                                                     */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC171pushnew(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4item;
  cl_object v5place;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4item = v6;
  }
  if (!(v3==ECL_NIL)){
   goto L10;
  }
  si_dm_too_few_arguments(v1);
L10:;
  {
   cl_object v6;
   v6 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v5place = v6;
  }
  {
   cl_object v6;                                  /*  VARS                    */
   cl_object v7;                                  /*  VALS                    */
   cl_object v8;                                  /*  STORES                  */
   cl_object v9;                                  /*  STORE-FORM              */
   cl_object v10;                                 /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v5place, v2env);
   {
    v6 = value0;
    v7 = cl_env_copy->values[1];
    v8 = cl_env_copy->values[2];
    v9 = cl_env_copy->values[3];
    v10 = cl_env_copy->values[4];
   }
   if (Null(L145trivial_setf_form(v5place, v6, v8, v9, v10))){
    goto L16;
   }
   T0 = cl_listX(4, ECL_SYM("ADJOIN",84), v4item, v5place, v3);
   value0 = cl_list(3, ECL_SYM("SETQ",754), v5place, T0);
   return value0;
L16:;
   if (cl_constantp(2, v4item, v2env)!=ECL_NIL) {
    goto L18;
   }
   v7 = CONS(v4item,v7);
   v4item = cl_gensym(0);
   v6 = CONS(v4item,v6);
L18:;
   T0 = (ECL_SYM("LIST",483)->symbol.gfdef);
   T1 = ecl_append(v6,v8);
   T2 = cl_listX(4, ECL_SYM("ADJOIN",84), v4item, v10, v3);
   T3 = ecl_list1(T2);
   T4 = ecl_append(v7,T3);
   T5 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(3, T0, T1, T4) /*  MAPCAR */;
   T6 = CONS(VV[128],v6);
   T7 = cl_list(2, ECL_SYM("DECLARE",276), T6);
   value0 = cl_list(4, ECL_SYM("LET*",480), T5, T7, v9);
   return value0;
  }
 }
}
static cl_object LC171pushnew_va(cl_narg narg, cl_object v6, cl_object v7env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[136]);
 {
  return LC171pushnew(v6, v7env);
 }
}
/* local function POP                                                         */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC172pop(cl_object v1, cl_object v2env)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  cl_object v4place;
  v3 = ecl_cdr(v1);
  if (!(v3==ECL_NIL)){
   goto L4;
  }
  si_dm_too_few_arguments(v1);
L4:;
  {
   cl_object v5;
   v5 = ecl_car(v3);
   v3 = ecl_cdr(v3);
   v4place = v5;
  }
  if (Null(v3)){
   goto L9;
  }
  si_dm_too_many_arguments(v1);
L9:;
  {
   cl_object v5;                                  /*  VARS                    */
   cl_object v6;                                  /*  VALS                    */
   cl_object v7;                                  /*  STORES                  */
   cl_object v8;                                  /*  STORE-FORM              */
   cl_object v9;                                  /*  ACCESS-FORM             */
   value0 = L92get_setf_expansion(2, v4place, v2env);
   {
    v5 = value0;
    v6 = cl_env_copy->values[1];
    v7 = cl_env_copy->values[2];
    v8 = cl_env_copy->values[3];
    v9 = cl_env_copy->values[4];
   }
   {
    cl_object v10store_var;
    v10store_var = ecl_car(v7);
    T0 = (ECL_SYM("LIST",483)->symbol.gfdef);
    T1 = ecl_append(v5,v7);
    T2 = ecl_list1(v9);
    T3 = ecl_append(v6,T2);
    T4 = (cl_env_copy->function=(ECL_SYM("MAPCAR",547)->symbol.gfdef))->cfun.entry(3, T0, T1, T3) /*  MAPCAR */;
    T5 = CONS(VV[128],v5);
    T6 = cl_list(2, ECL_SYM("DECLARE",276), T5);
    T7 = cl_list(2, ECL_SYM("CAR",182), v10store_var);
    T8 = cl_list(3, ECL_SYM("TRULY-THE",2081), ECL_SYM("LIST",483), v10store_var);
    T9 = cl_list(2, ECL_SYM("CDR",200), T8);
    T10 = cl_list(3, ECL_SYM("SETQ",754), v10store_var, T9);
    T11 = cl_list(4, ECL_SYM("PROG1",672), T7, T10, v8);
    value0 = cl_list(4, ECL_SYM("LET*",480), T4, T6, T11);
    return value0;
   }
  }
 }
}
static cl_object LC172pop_va(cl_narg narg, cl_object v5, cl_object v6env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[137]);
 {
  return LC172pop(v5, v6env);
 }
}
/* local function LAMBDA506                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC173__lambda506(cl_object v1, cl_object v2env)
{
 cl_object T0, T1;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = ecl_cdr(v1);
  {
   cl_object v4all_vars;
   cl_object v5all_vals;
   cl_object v6all_stores;
   cl_object v7all_storing_forms;
   cl_object v8all_get_forms;
   v4all_vars = ECL_NIL;
   v5all_vals = ECL_NIL;
   v6all_stores = ECL_NIL;
   v7all_storing_forms = ECL_NIL;
   v8all_get_forms = ECL_NIL;
   {
    cl_object v9;
    v9 = cl_reverse(v3);
    goto L12;
L11:;
    {
     cl_object v10item;
     v10item = ecl_car(v9);
     {
      cl_object v11;                              /*  VARS                    */
      cl_object v12;                              /*  VALS                    */
      cl_object v13;                              /*  STORES                  */
      cl_object v14;                              /*  STORING-FORM            */
      cl_object v15;                              /*  GET-FORM                */
      value0 = L92get_setf_expansion(2, v10item, v2env);
      {
       v11 = value0;
       v12 = cl_env_copy->values[1];
       v13 = cl_env_copy->values[2];
       v14 = cl_env_copy->values[3];
       v15 = cl_env_copy->values[4];
      }
      {
       cl_object v16extra;
       v16extra = ecl_cdr(v13);
       if (ecl_endp(v16extra)) {
        goto L18;
       }
       v11 = ecl_append(v16extra,v11);
       {
        cl_fixnum v17;
        v17 = ecl_length(v16extra);
        T0 = cl_make_list(1, ecl_make_fixnum(v17));
        v12 = ecl_append(T0,v12);
       }
       T0 = ecl_car(v13);
       v13 = ecl_list1(T0);
      }
L18:;
      v4all_vars = ecl_append(v11,v4all_vars);
      v5all_vals = ecl_append(v12,v5all_vals);
      v6all_stores = ecl_append(v13,v6all_stores);
      v7all_storing_forms = CONS(v14,v7all_storing_forms);
      v8all_get_forms = CONS(v15,v8all_get_forms);
     }
    }
    v9 = ecl_cdr(v9);
L12:;
    if (Null(v9)){
     goto L37;
    }
    goto L11;
L37:;
   }
   T0 = CONS(ECL_SYM("VALUES",899),v7all_storing_forms);
   T1 = CONS(ECL_SYM("VALUES",899),v8all_get_forms);
   cl_env_copy->nvalues = 5;
   cl_env_copy->values[4] = T1;
   cl_env_copy->values[3] = T0;
   cl_env_copy->values[2] = v6all_stores;
   cl_env_copy->values[1] = v5all_vals;
   cl_env_copy->values[0] = v4all_vars;
   return cl_env_copy->values[0];
  }
 }
}
static cl_object LC173__lambda506_va(cl_narg narg, cl_object v9, cl_object v10env, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[138]);
 {
  return LC173__lambda506(v9, v10env);
 }
}
/* closure LAMBDA15                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC88__lambda15(cl_narg narg, cl_object v1store, ...)
{
 cl_object T0, T1;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;
 CLV1 = _ecl_cdr(CLV2);                           /*  FUNCTION                */
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg<1)) FEwrong_num_arguments(VV[1]);
 {
  cl_object v2args;
  ecl_va_list args; ecl_va_start(args,v1store,narg,1);
  v2args = cl_grab_rest_args(args);
  ecl_va_end(args);
  T0 = ecl_list1(v1store);
  T1 = ecl_append(v2args,T0);
  value0 = CONS(ECL_CONS_CAR(CLV1),T1);
  cl_env_copy->nvalues = 1;
  return value0;
 }
 }
}
/* closure LAMBDA17                                                           */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC89__lambda17(cl_narg narg, cl_object v1args, cl_object v2env, ...)
{
 cl_object T0;
 cl_object CLV0, CLV1, CLV2;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV2 = env0;                                     /*  STORES-NO               */
 CLV1 = _ecl_cdr(CLV2);
 CLV0 = _ecl_cdr(CLV1);
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[2]);
 {
L1:;
  T0 = ecl_cdr(v1args);
  value0 = L87do_setf_method_expansion(4, ECL_CONS_CAR(CLV0), ECL_CONS_CAR(CLV1), T0, ECL_CONS_CAR(CLV2));
  return value0;
 }
 }
}
/* local function LAMBDA268                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC151__lambda268(cl_object v1x, cl_object v2y)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = (ECL_SYM("LIST",483)->symbol.gfdef);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    v7 = ecl_car(v2y);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
   {
    cl_object v7;
    cl_object v8;
    cl_object v9;
    {
     cl_object v10;
     v10 = ecl_cadr(v2y);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    v8 = ECL_NIL;
    v9 = v7;
    {
     cl_object v10;
     cl_object v11;
     v10 = ecl_list1(ECL_NIL);
     v11 = v10;
L16:;
     if (!(ecl_endp(v6))){
      goto L18;
     }
     goto L17;
L18:;
     v5 = ECL_CONS_CAR(v6);
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v12;
     }
     if (!(ecl_endp(v9))){
      goto L26;
     }
     goto L17;
L26:;
     v8 = ECL_CONS_CAR(v9);
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v12;
     }
     {
      cl_object v12;
      v12 = v11;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v12;
     }
     T2 = ecl_function_dispatch(cl_env_copy,v3)(2, v5, v8);
     v11 = ecl_list1(T2);
     (ECL_CONS_CDR(T1)=v11,T1);
     goto L16;
L17:;
     T0 = ecl_cdr(v10);
     goto L2;
    }
   }
  }
 }
L2:;
 T1 = ecl_car(v1x);
 T2 = CONS(T0,T1);
 T3 = ecl_caddr(v2y);
 T4 = ecl_cadr(v1x);
 T5 = CONS(T3,T4);
 T6 = ecl_cadddr(v2y);
 T7 = ecl_caddr(v1x);
 T8 = CONS(T6,T7);
 T9 = ecl_cddddr(v2y);
 T10 = ecl_car(T9);
 T11 = ecl_cadddr(v1x);
 T12 = CONS(T10,T11);
 value0 = cl_list(4, T2, T5, T8, T12);
 return value0;
}
static cl_object LC151__lambda268_va(cl_narg narg, cl_object v3x, cl_object v4y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[82]);
 {
  return LC151__lambda268(v3x, v4y);
 }
}
/* closure LAMBDA286                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC152__lambda286(cl_narg narg, cl_object v1place, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ENV                     */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[88]);
 {
L1:;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   cl_env_copy->values[0] = L92get_setf_expansion(2, v1place, ECL_CONS_CAR(CLV0));
   ecl_stack_frame_push_values(_ecl_inner_frame);
   value0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
   ecl_stack_frame_close(_ecl_inner_frame);
   return value0;
  }
 }
 }
}
/* local function THUNK                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC153thunk(volatile cl_object *lex0, cl_object v1pairs, cl_object v2stores, cl_object v3access_forms)
{
 cl_object T0, T1, T2, T3, T4, T5, T6;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v2stores)){
  goto L2;
 }
 T0 = ecl_car(v1pairs);
 T1 = ecl_car(v2stores);
 T2 = ecl_car(v3access_forms);
 T4 = ecl_cdr(v1pairs);
 T5 = ecl_cdr(v2stores);
 T6 = ecl_cdr(v3access_forms);
 T3 = LC153thunk(lex0, T4, T5, T6);
 T4 = cl_listX(4, ECL_SYM("MULTIPLE-VALUE-BIND",574), T1, T2, T3);
 T5 = cl_list(3, ECL_SYM("LET",479), T0, T4);
 value0 = ecl_list1(T5);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = lex0[0];
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function LAMBDA324                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC156__lambda324(cl_object v1x, cl_object v2y)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = (ECL_SYM("LIST",483)->symbol.gfdef);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    v7 = ecl_car(v2y);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
   {
    cl_object v7;
    cl_object v8;
    cl_object v9;
    {
     cl_object v10;
     v10 = ecl_cadr(v2y);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    v8 = ECL_NIL;
    v9 = v7;
    {
     cl_object v10;
     cl_object v11;
     v10 = ecl_list1(ECL_NIL);
     v11 = v10;
L16:;
     if (!(ecl_endp(v6))){
      goto L18;
     }
     goto L17;
L18:;
     v5 = ECL_CONS_CAR(v6);
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v12;
     }
     if (!(ecl_endp(v9))){
      goto L26;
     }
     goto L17;
L26:;
     v8 = ECL_CONS_CAR(v9);
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v12;
     }
     {
      cl_object v12;
      v12 = v11;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v12;
     }
     T2 = ecl_function_dispatch(cl_env_copy,v3)(2, v5, v8);
     v11 = ecl_list1(T2);
     (ECL_CONS_CDR(T1)=v11,T1);
     goto L16;
L17:;
     T0 = ecl_cdr(v10);
     goto L2;
    }
   }
  }
 }
L2:;
 T1 = ecl_car(v1x);
 T2 = CONS(T0,T1);
 T3 = ecl_caddr(v2y);
 T4 = ecl_cadr(v1x);
 T5 = CONS(T3,T4);
 T6 = ecl_cadddr(v2y);
 T7 = ecl_caddr(v1x);
 T8 = CONS(T6,T7);
 T9 = ecl_cddddr(v2y);
 T10 = ecl_car(T9);
 T11 = ecl_cadddr(v1x);
 T12 = CONS(T10,T11);
 value0 = cl_list(4, T2, T5, T8, T12);
 return value0;
}
static cl_object LC156__lambda324_va(cl_narg narg, cl_object v3x, cl_object v4y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[101]);
 {
  return LC156__lambda324(v3x, v4y);
 }
}
/* closure LAMBDA342                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC157__lambda342(cl_narg narg, cl_object v1place, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ENV                     */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[102]);
 {
L1:;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   cl_env_copy->values[0] = L92get_setf_expansion(2, v1place, ECL_CONS_CAR(CLV0));
   ecl_stack_frame_push_values(_ecl_inner_frame);
   value0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
   ecl_stack_frame_close(_ecl_inner_frame);
   return value0;
  }
 }
 }
}
/* local function THUNK                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC158thunk(volatile cl_object *lex0, cl_object v1stores, cl_object v2access_forms)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1stores)){
  goto L2;
 }
 T0 = ecl_car(v1stores);
 T1 = ecl_car(v2access_forms);
 T3 = ecl_cdr(v1stores);
 T4 = ecl_cdr(v2access_forms);
 T2 = LC158thunk(lex0, T3, T4);
 T3 = cl_listX(4, ECL_SYM("MULTIPLE-VALUE-BIND",574), T0, T1, T2);
 value0 = ecl_list1(T3);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = lex0[0];
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function LAMBDA366                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC160__lambda366(cl_object v1x, cl_object v2y)
{
 cl_object T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 {
  cl_object v3;
  v3 = (ECL_SYM("LIST",483)->symbol.gfdef);
  {
   cl_object v4;
   cl_object v5;
   cl_object v6;
   {
    cl_object v7;
    v7 = ecl_car(v2y);
    if (ecl_unlikely(!ECL_LISTP(v7))) FEtype_error_list(v7);
    value0 = ECL_NIL;
    cl_env_copy->nvalues = 0;
    v4 = v7;
   }
   v5 = ECL_NIL;
   v6 = v4;
   {
    cl_object v7;
    cl_object v8;
    cl_object v9;
    {
     cl_object v10;
     v10 = ecl_cadr(v2y);
     if (ecl_unlikely(!ECL_LISTP(v10))) FEtype_error_list(v10);
     value0 = ECL_NIL;
     cl_env_copy->nvalues = 0;
     v7 = v10;
    }
    v8 = ECL_NIL;
    v9 = v7;
    {
     cl_object v10;
     cl_object v11;
     v10 = ecl_list1(ECL_NIL);
     v11 = v10;
L16:;
     if (!(ecl_endp(v6))){
      goto L18;
     }
     goto L17;
L18:;
     v5 = ECL_CONS_CAR(v6);
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v6);
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v6 = v12;
     }
     if (!(ecl_endp(v9))){
      goto L26;
     }
     goto L17;
L26:;
     v8 = ECL_CONS_CAR(v9);
     {
      cl_object v12;
      v12 = ECL_CONS_CDR(v9);
      if (ecl_unlikely(!ECL_LISTP(v12))) FEtype_error_list(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      v9 = v12;
     }
     {
      cl_object v12;
      v12 = v11;
      if (ecl_unlikely(ECL_ATOM(v12))) FEtype_error_cons(v12);
      value0 = ECL_NIL;
      cl_env_copy->nvalues = 0;
      T1 = v12;
     }
     T2 = ecl_function_dispatch(cl_env_copy,v3)(2, v5, v8);
     v11 = ecl_list1(T2);
     (ECL_CONS_CDR(T1)=v11,T1);
     goto L16;
L17:;
     T0 = ecl_cdr(v10);
     goto L2;
    }
   }
  }
 }
L2:;
 T1 = ecl_car(v1x);
 T2 = CONS(T0,T1);
 T3 = ecl_caddr(v2y);
 T4 = ecl_cadr(v1x);
 T5 = CONS(T3,T4);
 T6 = ecl_cadddr(v2y);
 T7 = ecl_caddr(v1x);
 T8 = CONS(T6,T7);
 T9 = ecl_cddddr(v2y);
 T10 = ecl_car(T9);
 T11 = ecl_cadddr(v1x);
 T12 = CONS(T10,T11);
 value0 = cl_list(4, T2, T5, T8, T12);
 return value0;
}
static cl_object LC160__lambda366_va(cl_narg narg, cl_object v3x, cl_object v4y, ...)
{
 if (ecl_unlikely(narg!=2)) FEwrong_num_arguments(VV[104]);
 {
  return LC160__lambda366(v3x, v4y);
 }
}
/* closure LAMBDA384                                                          */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC161__lambda384(cl_narg narg, cl_object v1place, ...)
{
 cl_object CLV0;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object env0 = cl_env_copy->function->cclosure.env;
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
 /* Scanning closure data ... */
 CLV0 = env0;                                     /*  ENV                     */
 { /* ... closure scanning finished */
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[105]);
 {
L1:;
  {
   struct ecl_stack_frame _ecl_inner_frame_aux;
   cl_object _ecl_inner_frame=ecl_stack_frame_open(cl_env_copy,(cl_object)&_ecl_inner_frame_aux,0);
   cl_env_copy->values[0] = L92get_setf_expansion(2, v1place, ECL_CONS_CAR(CLV0));
   ecl_stack_frame_push_values(_ecl_inner_frame);
   value0 = ecl_apply_from_stack_frame(_ecl_inner_frame,ECL_SYM("LIST",483));
   ecl_stack_frame_close(_ecl_inner_frame);
   return value0;
  }
 }
 }
}
/* local function THUNK                                                       */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC162thunk(volatile cl_object *lex0, cl_object v1stores, cl_object v2access_forms)
{
 cl_object T0, T1, T2, T3, T4;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 if (Null(v1stores)){
  goto L2;
 }
 T0 = ecl_car(v1stores);
 T1 = ecl_car(v2access_forms);
 T3 = ecl_cdr(v1stores);
 T4 = ecl_cdr(v2access_forms);
 T2 = LC162thunk(lex0, T3, T4);
 T3 = cl_listX(4, ECL_SYM("MULTIPLE-VALUE-BIND",574), T0, T1, T2);
 value0 = ecl_list1(T3);
 cl_env_copy->nvalues = 1;
 return value0;
L2:;
 value0 = lex0[0];
 cl_env_copy->nvalues = 1;
 return value0;
}
/* local function LAMBDA431                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC166__lambda431(cl_object v1v)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_gensym(0);
 value0 = cl_list(2, T0, v1v);
 return value0;
}
static cl_object LC166__lambda431_va(cl_narg narg, cl_object v2v, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[131]);
 {
  return LC166__lambda431(v2v);
 }
}
/* local function LAMBDA445                                                   */
/* optimize speed 1, debug 1, space 1, safety 2                               */
static cl_object LC168__lambda445(cl_object v1v)
{
 cl_object T0;
 cl_object env0 = ECL_NIL;
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 ecl_cs_check(cl_env_copy,value0);
L1:;
 T0 = cl_gensym(0);
 value0 = cl_list(2, T0, v1v);
 return value0;
}
static cl_object LC168__lambda445_va(cl_narg narg, cl_object v2v, ...)
{
 if (ecl_unlikely(narg!=1)) FEwrong_num_arguments(VV[133]);
 {
  return LC168__lambda445(v2v);
 }
}
#include "lsp/setf.data"
#ifdef __cplusplus
extern "C"
#endif

ECL_DLLEXPORT void _ecldsIhADcO3Hii9_YlbzL881(cl_object flag)
{
 const cl_env_ptr cl_env_copy = ecl_process_env();
 cl_object value0;
 cl_object *VVtemp;
 if (flag != OBJNULL){
 Cblock = flag;
 #ifndef ECL_DYNAMIC_VV
 flag->cblock.data = VV;
 #endif
 flag->cblock.data_size = VM;
 flag->cblock.temp_data_size = VMtemp;
 flag->cblock.data_text = compiler_data_text;
 flag->cblock.cfuns_size = compiler_cfuns_size;
 flag->cblock.cfuns = compiler_cfuns;
 flag->cblock.source = ecl_make_constant_base_string("SRC:LSP;SETF.LSP.NEWEST",-1);
 return;}
 #ifdef ECL_DYNAMIC_VV
 VV = Cblock->cblock.data;
 #endif
 Cblock->cblock.data_text = (const cl_object *)"@EcLtAg:_ecldsIhADcO3Hii9_YlbzL881@";
 VVtemp = Cblock->cblock.temp_data;
 ECL_DEFINE_SETF_FUNCTIONS
 {
  cl_object T0;
  cl_object volatile env0 = ECL_NIL;
/* MAKE-LOAD-FORMs                                                            */
/* TOP-LEVEL-FORMs                                                            */
  si_select_package(VVtemp[0]);
  (void)0; /* No entry created for DO-SETF-METHOD-EXPANSION */
  (void)0; /* No entry created for DO-DEFSETF */
  (void)0; /* No entry created for DO-DEFINE-SETF-METHOD */
  ecl_cmp_defmacro(VV[139]);                      /*  DEFSETF                 */
  ecl_cmp_defmacro(VV[140]);                      /*  DEFINE-SETF-EXPANDER    */
  ecl_cmp_defun(VV[141]);                         /*  GET-SETF-EXPANSION      */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC93__lambda38_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAR",182), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC94__lambda40_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDR",200), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC95__lambda42_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAAR",173), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC96__lambda44_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDAR",192), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC97__lambda46_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CADR",180), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC98__lambda48_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDDR",199), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC99__lambda50_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAAAR",169), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC100__lambda52_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDAAR",188), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC101__lambda54_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CADAR",176), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC102__lambda56_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDDAR",195), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC103__lambda58_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAADR",172), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC104__lambda60_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDADR",191), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC105__lambda62_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CADDR",179), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC106__lambda64_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDDDR",198), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC107__lambda66_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAAAAR",167), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC108__lambda68_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDAAAR",186), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC109__lambda70_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CADAAR",174), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC110__lambda72_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDDAAR",193), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC111__lambda74_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAADAR",170), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC112__lambda76_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDADAR",189), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC113__lambda78_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CADDAR",177), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC114__lambda80_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDDDAR",196), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC115__lambda82_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAAADR",168), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC116__lambda84_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDAADR",187), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC117__lambda86_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CADADR",175), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC118__lambda88_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDDADR",194), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC119__lambda90_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CAADDR",171), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC120__lambda92_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDADDR",190), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC121__lambda94_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CADDDR",178), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC122__lambda96_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("CDDDDR",197), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC123__lambda98_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("FIRST",373), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC124__lambda100_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("SECOND",743), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC125__lambda102_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("THIRD",860), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC126__lambda104_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("FOURTH",391), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC127__lambda106_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("FIFTH",353), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC128__lambda108_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("SIXTH",785), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC129__lambda110_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("SEVENTH",755), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC130__lambda112_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("EIGHTH",328), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC131__lambda114_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("NINTH",585), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC132__lambda116_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("TENTH",857), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC133__lambda118_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("REST",722), T0, ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("SVREF",841), ECL_SYM("SVSET",1183), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("ELT",329), ECL_SYM("ELT-SET",1075), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("SYMBOL-VALUE",849), ECL_SYM("SET",746), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("SYMBOL-FUNCTION",844), ECL_SYM("FSET",1090), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("FDEFINITION",351), ECL_SYM("FSET",1090), ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC134__lambda125,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("MACRO-FUNCTION",520), T0, ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("AREF",94), ECL_SYM("ASET",1045), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("ROW-MAJOR-AREF",734), ECL_SYM("ROW-MAJOR-ASET",1156), ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC135__lambda129,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("GET",404), T0, ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("GET-SYSPROP",1093), ECL_SYM("PUT-SYSPROP",1150), ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC136__lambda132_va,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("NTH",604), T0, ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("CHAR",205), ECL_SYM("CHAR-SET",1057), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("SCHAR",741), ECL_SYM("SCHAR-SET",1159), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("BIT",125), ECL_SYM("ASET",1045), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("SBIT",739), ECL_SYM("ASET",1045), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("FILL-POINTER",364), ECL_SYM("FILL-POINTER-SET",1080), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("SYMBOL-PLIST",848), ECL_SYM("SET-SYMBOL-PLIST",1163), ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC137__lambda140,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("GETHASH",415), T0, ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("INSTANCE-REF",1196), ECL_SYM("INSTANCE-SET",1197), ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC138__lambda143_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("COMPILER-MACRO-FUNCTION",241), T0, ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("READTABLE-CASE",704), ECL_SYM("READTABLE-CASE-SET",1152), ecl_make_int8_t(1));
  si_do_defsetf(3, ECL_SYM("STREAM-EXTERNAL-FORMAT",806), ECL_SYM("STREAM-EXTERNAL-FORMAT-SET",1808), ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC139__lambda149_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_define_setf_method(ECL_SYM("GETF",414), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC140__lambda153,ECL_NIL,Cblock,3);
   T0 = v1;
  }
  si_do_defsetf(3, ECL_SYM("SUBSEQ",832), T0, ecl_make_int8_t(1));
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC141__lambda157_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_define_setf_method(ECL_SYM("THE",859), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC142__lambda163_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_define_setf_method(ECL_SYM("APPLY",91), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC143__lambda168_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_define_setf_method(ECL_SYM("LDB",459), T0);
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC144__lambda174_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_define_setf_method(ECL_SYM("MASK-FIELD",552), T0);
  (void)0; /* No entry created for TRIVIAL-SETF-FORM */
  (void)0; /* No entry created for TRY-SIMPLER-EXPANSION */
  (void)0; /* No entry created for SETF-EXPAND-1 */
  (void)0; /* No entry created for SETF-EXPAND */
  ecl_cmp_defmacro(VV[142]);                      /*  SETF                    */
  ecl_cmp_defmacro(VV[143]);                      /*  WITH-SETF-EXPANSIONS    */
  ecl_cmp_defmacro(VV[144]);                      /*  PSETF                   */
  ecl_cmp_defmacro(VV[145]);                      /*  WITH-EXPANSION-SETTER   */
  ecl_cmp_defmacro(VV[146]);                      /*  SHIFTF                  */
  ecl_cmp_defmacro(VV[147]);                      /*  ROTATEF                 */
  ecl_cmp_defmacro(VV[148]);                      /*  DEFINE-MODIFY-MACRO     */
  ecl_cmp_defmacro(VV[149]);                      /*  REMF                    */
  ecl_cmp_defmacro(VV[150]);                      /*  INCF                    */
  ecl_cmp_defmacro(VV[151]);                      /*  DECF                    */
  ecl_cmp_defmacro(VV[152]);                      /*  PUSH                    */
  ecl_cmp_defmacro(VV[153]);                      /*  PUSHNEW                 */
  ecl_cmp_defmacro(VV[154]);                      /*  POP                     */
  {
   cl_object volatile v1;
   v1 = ecl_make_cfun_va((cl_objectfn)LC173__lambda506_va,ECL_NIL,Cblock,2);
   T0 = v1;
  }
  si_do_define_setf_method(ECL_SYM("VALUES",899), T0);
 }
}
